
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_b_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.127458'}

wordnet_terms_b = [
    'ba',
    'baa',
    'baal',
    'baas',
    'baba',
    'babar',
    'babassu',
    'babbitt',
    'babbitting',
    'babble',
    'babbled',
    'babbler',
    'babblers',
    'babbling',
    'babe',
    'babel',
    'babelike',
    'babesiidae',
    'babies',
    'babinski',
    'babiroussa',
    'babirusa',
    'babirussa',
    'babka',
    'baboo',
    'baboon',
    'baboonish',
    'baboons',
    'babu',
    'babushka',
    'baby',
    'babyhood',
    'babyish',
    'babylon',
    'babylonia',
    'babylonian',
    'babylonians',
    'babyminder',
    'babyrousa',
    'babysit',
    'babysitter',
    'babysitting',
    'babytalk',
    'bacca',
    'baccalaureate',
    'baccarat',
    'baccate',
    'bacchanal',
    'bacchanalia',
    'bacchanalian',
    'bacchant',
    'bacchante',
    'bacchantic',
    'baccharis',
    'bacchic',
    'bacchus',
    'bacciferous',
    'baccivorous',
    'baccy',
    'bach',
    'bachelor',
    'bachelorette',
    'bachelorhood',
    'bacillaceae',
    'bacillar',
    'bacillariophyceae',
    'bacillary',
    'bacilli',
    'bacilliform',
    'bacillus',
    'bacitracin',
    'back',
    'backache',
    'backband',
    'backbeat',
    'backbench',
    'backbencher',
    'backbenchers',
    'backbend',
    'backbends',
    'backbite',
    'backbiter',
    'backblast',
    'backboard',
    'backbone',
    'backbreaking',
    'backchat',
    'backcloth',
    'backcross',
    'backdate',
    'backdated',
    'backdoor',
    'backdown',
    'backdrop',
    'backed',
    'backer',
    'backetball',
    'backfield',
    'backfire',
    'backfires',
    'backflow',
    'backflowing',
    'backgammon',
    'background',
    'backgrounder',
    'backgrounding',
    'backgrounds',
    'backhand',
    'backhanded',
    'backhander',
    'backhoe',
    'backing',
    'backlash',
    'backlashed',
    'backless',
    'backlighting',
    'backlog',
    'backmost',
    'backpack',
    'backpacker',
    'backpacking',
    'backpedal',
    'backplate',
    'backrest',
    'backroom',
    'backs',
    'backsaw',
    'backscatter',
    'backscratcher',
    'backseat',
    'backsheesh',
    'backside',
    'backslap',
    'backslapper',
    'backslapping',
    'backslide',
    'backslider',
    'backsliding',
    'backspace',
    'backspacer',
    'backspin',
    'backstage',
    'backstair',
    'backstairs',
    'backstay',
    'backstitch',
    'backstitches',
    'backstop',
    'backstroke',
    'backstroker',
    'backswept',
    'backswimmer',
    'backswimmers',
    'backsword',
    'backtalk',
    'backtrack',
    'backup',
    'backups',
    'backward',
    'backwardness',
    'backwards',
    'backwash',
    'backwater',
    'backwaters',
    'backwoods',
    'backwoodsman',
    'backyard',
    'bacon',
    'bacteremia',
    'bacteremic',
    'bacteria',
    'bacteriacide',
    'bacteriaemia',
    'bacterial',
    'bactericidal',
    'bactericide',
    'bacteriemia',
    'bacteriochlorophyll',
    'bacterioid',
    'bacterioidal',
    'bacteriologic',
    'bacteriological',
    'bacteriologist',
    'bacteriology',
    'bacteriolysis',
    'bacteriolytic',
    'bacteriophage',
    'bacteriophages',
    'bacteriophagic',
    'bacteriophagous',
    'bacteriostasis',
    'bacteriostat',
    'bacteriostatic',
    'bacterise',
    'bacterium',
    'bacterize',
    'bacteroid',
    'bacteroidaceae',
    'bacteroidal',
    'bacteroides',
    'baculiform',
    'bad',
    'badaga',
    'baddeleyite',
    'baddie',
    'bade',
    'badge',
    'badger',
    'badgerer',
    'badgering',
    'badgers',
    'badges',
    'badinage',
    'badlands',
    'badly',
    'badminton',
    'badmouth',
    'badmouths',
    'badness',
    'baeda',
    'baedeker',
    'baffle',
    'baffled',
    'bafflement',
    'baffles',
    'baffling',
    'bag',
    'bagascosis',
    'bagasse',
    'bagassosis',
    'bagatelle',
    'bagdad',
    'bagehot',
    'bagel',
    'bagels',
    'bagful',
    'baggage',
    'baggageman',
    'bagged',
    'bagger',
    'bagging',
    'baggy',
    'baghdad',
    'bagman',
    'bagnio',
    'bagpipe',
    'bagpiper',
    'bagpipes',
    'bags',
    'baguet',
    'baguette',
    'baguettes',
    'bahai',
    'bahaism',
    'bahama',
    'bahamas',
    'bahamian',
    'bahasa',
    'bahrain',
    'bahraini',
    'bahrein',
    'bahreini',
    'baht',
    'bai',
    'baic',
    'baikal',
    'bail',
    'bailable',
    'bailee',
    'bailey',
    'bailiff',
    'bailiffship',
    'bailing',
    'bailiwick',
    'bailment',
    'bailor',
    'baiomys',
    'bairava',
    'bairdiella',
    'bairiki',
    'bairn',
    'baisa',
    'baisakh',
    'bait',
    'baited',
    'baiting',
    'baits',
    'baiza',
    'baize',
    'baja',
    'bake',
    'bakeapple',
    'baked',
    'bakehouse',
    'bakelite',
    'baker',
    'bakeries',
    'bakers',
    'bakersfield',
    'bakery',
    'bakes',
    'bakeshop',
    'baking',
    'bakke',
    'baklava',
    'baksheesh',
    'bakshis',
    'bakshish',
    'baku',
    'bakunin',
    'balaclava',
    'balaena',
    'balaeniceps',
    'balaenicipitidae',
    'balaenidae',
    'balaenoptera',
    'balaenopteridae',
    'balagan',
    'balalaika',
    'balance',
    'balanced',
    'balancer',
    'balances',
    'balanchine',
    'balancing',
    'balanidae',
    'balanitis',
    'balanoposthitis',
    'balanus',
    'balarama',
    'balas',
    'balata',
    'balaton',
    'balboa',
    'balbriggan',
    'balconied',
    'balconies',
    'balcony',
    'bald',
    'baldachin',
    'balder',
    'balderdash',
    'baldhead',
    'balding',
    'baldness',
    'baldpate',
    'baldr',
    'baldric',
    'baldrick',
    'baldwin',
    'baldy',
    'bale',
    'balearic',
    'baleen',
    'balefire',
    'baleful',
    'balefulness',
    'balenciaga',
    'bales',
    'balfour',
    'bali',
    'balibago',
    'balinese',
    'balistes',
    'balistidae',
    'balk',
    'balkan',
    'balkanise',
    'balkanize',
    'balkans',
    'balker',
    'balkiness',
    'balking',
    'balkline',
    'balky',
    'ball',
    'ballad',
    'ballade',
    'balladeer',
    'ballads',
    'ballast',
    'ballcock',
    'balldress',
    'ballerina',
    'ballerinas',
    'ballet',
    'balletic',
    'balletomane',
    'balletomania',
    'ballets',
    'ballgame',
    'ballista',
    'ballistic',
    'ballistics',
    'ballistite',
    'ballistocardiogram',
    'ballistocardiograph',
    'ballock',
    'balloon',
    'balloonfish',
    'ballooning',
    'balloonist',
    'balloons',
    'ballot',
    'ballota',
    'balloting',
    'ballots',
    'ballottement',
    'ballpark',
    'ballpen',
    'ballplayer',
    'ballpoint',
    'ballroom',
    'balls',
    'ballup',
    'bally',
    'ballyhoo',
    'ballyrag',
    'balm',
    'balminess',
    'balmoral',
    'balmy',
    'balochi',
    'baloney',
    'balsa',
    'balsam',
    'balsamic',
    'balsaminaceae',
    'balsamorhiza',
    'balsamroot',
    'balsams',
    'balsamy',
    'balsawood',
    'balthasar',
    'balthazar',
    'baltic',
    'baltimore',
    'baluchi',
    'baluster',
    'balusters',
    'balustrade',
    'balzac',
    'balzacian',
    'bam',
    'bamako',
    'bambino',
    'bamboo',
    'bamboos',
    'bamboozle',
    'bamboozled',
    'bambusa',
    'bambuseae',
    'ban',
    'banal',
    'banality',
    'banana',
    'bananas',
    'banausic',
    'band',
    'bandage',
    'bandaged',
    'bandages',
    'bandaging',
    'bandana',
    'bandanna',
    'bandbox',
    'bandeau',
    'banded',
    'bandelet',
    'bandelette',
    'banderilla',
    'banderillero',
    'bandfish',
    'bandicoot',
    'bandicoots',
    'bandied',
    'banding',
    'bandit',
    'banditry',
    'bandits',
    'bandleader',
    'bandlet',
    'bandmaster',
    'bandoleer',
    'bandolier',
    'bandoneon',
    'bands',
    'bandsaw',
    'bandsman',
    'bandstand',
    'bandtail',
    'bandung',
    'bandwagon',
    'bandwidth',
    'bandy',
    'bandyleg',
    'bane',
    'baneberry',
    'baneful',
    'banff',
    'bang',
    'bangalore',
    'banged',
    'banger',
    'bangiaceae',
    'banging',
    'bangkok',
    'bangla',
    'bangladesh',
    'bangladeshi',
    'bangle',
    'bangor',
    'bangtail',
    'bangui',
    'bani',
    'banian',
    'banish',
    'banished',
    'banishing',
    'banishment',
    'banister',
    'banjo',
    'banjos',
    'banjul',
    'bank',
    'bankable',
    'bankbook',
    'banked',
    'banker',
    'bankers',
    'bankhead',
    'bankia',
    'banking',
    'banknote',
    'banknotes',
    'bankroll',
    'bankrupt',
    'bankruptcy',
    'banks',
    'banksia',
    'banned',
    'banner',
    'banneret',
    'banners',
    'banning',
    'bannister',
    'bannock',
    'bannockburn',
    'banns',
    'banquet',
    'banqueting',
    'banquets',
    'banquette',
    'bans',
    'banshee',
    'banshie',
    'bantam',
    'bantamweight',
    'banteng',
    'banter',
    'bantering',
    'banting',
    'banto',
    'bantoid',
    'bantu',
    'banyan',
    'banzai',
    'baobab',
    'bap',
    'baphia',
    'baptise',
    'baptised',
    'baptisia',
    'baptising',
    'baptism',
    'baptismal',
    'baptist',
    'baptistery',
    'baptistic',
    'baptistry',
    'baptists',
    'baptize',
    'baptized',
    'baptizing',
    'bar',
    'baraka',
    'baranduki',
    'barany',
    'barb',
    'barbacan',
    'barbadian',
    'barbados',
    'barbarea',
    'barbarian',
    'barbarians',
    'barbaric',
    'barbarisation',
    'barbarise',
    'barbarism',
    'barbarity',
    'barbarization',
    'barbarize',
    'barbarized',
    'barbarossa',
    'barbarous',
    'barbarousness',
    'barbary',
    'barbasco',
    'barbate',
    'barbecue',
    'barbecued',
    'barbecuing',
    'barbed',
    'barbel',
    'barbell',
    'barbellate',
    'barbells',
    'barbels',
    'barbeque',
    'barber',
    'barberry',
    'barbers',
    'barbershop',
    'barbet',
    'barbets',
    'barbette',
    'barbican',
    'barbital',
    'barbitone',
    'barbiturate',
    'barbs',
    'barbu',
    'barbuda',
    'barbwire',
    'barcarole',
    'barcarolle',
    'barcelona',
    'bard',
    'barde',
    'bardeen',
    'bardic',
    'bardolatry',
    'bare',
    'bareback',
    'barebacked',
    'bareboat',
    'bareboating',
    'bared',
    'barefaced',
    'barefoot',
    'barefooted',
    'barehanded',
    'bareheaded',
    'barelegged',
    'barely',
    'barenboim',
    'bareness',
    'barents',
    'barf',
    'bargain',
    'bargained',
    'bargainer',
    'bargaining',
    'bargains',
    'barge',
    'barged',
    'bargee',
    'bargello',
    'bargeman',
    'barges',
    'bari',
    'baric',
    'barilla',
    'baring',
    'barish',
    'barite',
    'baritone',
    'barium',
    'bark',
    'barked',
    'barkeep',
    'barkeeper',
    'barker',
    'barking',
    'barkley',
    'barks',
    'barky',
    'barley',
    'barleycorn',
    'barm',
    'barmaid',
    'barman',
    'barmbrack',
    'barmy',
    'barn',
    'barnacle',
    'barnacles',
    'barnburner',
    'barndoor',
    'barnes',
    'barnful',
    'barns',
    'barnstorm',
    'barnstormer',
    'barnstorming',
    'barnum',
    'barnyard',
    'barograph',
    'barographic',
    'barometer',
    'barometric',
    'barometrical',
    'baron',
    'baronage',
    'baronduki',
    'baroness',
    'baronet',
    'baronetage',
    'baronetcy',
    'baronetise',
    'baronetize',
    'baronetized',
    'baronets',
    'barong',
    'baronial',
    'barons',
    'barony',
    'baroque',
    'baroqueness',
    'baroreceptor',
    'barosaur',
    'barosaurus',
    'barouche',
    'barque',
    'barrack',
    'barracking',
    'barracks',
    'barracouta',
    'barracuda',
    'barrage',
    'barraged',
    'barramundi',
    'barranquilla',
    'barrater',
    'barrator',
    'barratry',
    'barred',
    'barrel',
    'barreled',
    'barrelfish',
    'barrelful',
    'barrelhouse',
    'barrelled',
    'barrels',
    'barren',
    'barrenness',
    'barrens',
    'barrenwort',
    'barrett',
    'barrette',
    'barretter',
    'barricade',
    'barricaded',
    'barricades',
    'barricado',
    'barrie',
    'barrier',
    'barriers',
    'barring',
    'barrio',
    'barrister',
    'barroom',
    'barrow',
    'barrowful',
    'barrymore',
    'bars',
    'barstow',
    'bart',
    'bartender',
    'barter',
    'barterer',
    'bartering',
    'barth',
    'barthelme',
    'bartholdi',
    'bartholin',
    'bartle',
    'bartlesville',
    'bartlett',
    'bartok',
    'bartolomeo',
    'bartonia',
    'bartramia',
    'baruch',
    'barunduki',
    'barycenter',
    'barye',
    'baryon',
    'baryons',
    'baryshnikov',
    'baryta',
    'barytes',
    'barytic',
    'barytone',
    'basal',
    'basalt',
    'basaltic',
    'bascule',
    'base',
    'baseball',
    'baseboard',
    'baseborn',
    'based',
    'basel',
    'baseless',
    'baseline',
    'baseman',
    'basement',
    'baseness',
    'basenji',
    'baser',
    'bases',
    'bash',
    'bashful',
    'bashfulness',
    'basia',
    'basic',
    'basically',
    'basics',
    'basidia',
    'basidial',
    'basidiocarp',
    'basidiolichen',
    'basidiomycete',
    'basidiomycetes',
    'basidiomycetous',
    'basidiomycota',
    'basidiomycotina',
    'basidiospore',
    'basidiospores',
    'basidiosporous',
    'basidium',
    'basifixed',
    'basify',
    'basil',
    'basilar',
    'basilary',
    'basileus',
    'basilic',
    'basilica',
    'basilican',
    'basilicata',
    'basiliscus',
    'basilisk',
    'basin',
    'basinal',
    'basined',
    'basinet',
    'basinful',
    'basing',
    'basins',
    'basipetal',
    'basis',
    'basiscopic',
    'bask',
    'basked',
    'basket',
    'basketball',
    'basketeer',
    'basketful',
    'basketmaker',
    'basketry',
    'baskets',
    'basketweaver',
    'basking',
    'basks',
    'basle',
    'basophil',
    'basophile',
    'basophilia',
    'basophilic',
    'basophils',
    'basotho',
    'basque',
    'basra',
    'bass',
    'bassariscidae',
    'bassariscus',
    'bassarisk',
    'basses',
    'basset',
    'basseterre',
    'bassia',
    'bassine',
    'bassinet',
    'bassist',
    'basso',
    'bassoon',
    'bassoonist',
    'bassoons',
    'basswood',
    'bast',
    'bastard',
    'bastardisation',
    'bastardise',
    'bastardised',
    'bastardization',
    'bastardize',
    'bastardized',
    'bastardly',
    'bastardy',
    'baste',
    'baster',
    'bastes',
    'bastille',
    'bastinado',
    'basting',
    'bastion',
    'bastioned',
    'bastions',
    'bastnaesite',
    'bastnasite',
    'basuco',
    'basuto',
    'basutoland',
    'bat',
    'bata',
    'bataan',
    'batch',
    'bate',
    'bated',
    'batfish',
    'batfishes',
    'batfowl',
    'bath',
    'bathe',
    'bathed',
    'bather',
    'bathers',
    'bathetic',
    'bathhouse',
    'bathing',
    'batholite',
    'batholith',
    'batholithic',
    'batholitic',
    'bathometer',
    'bathos',
    'bathrobe',
    'bathroom',
    'bathrooms',
    'baths',
    'bathsheba',
    'bathtub',
    'bathyal',
    'bathyergidae',
    'bathyergus',
    'bathymeter',
    'bathymetric',
    'bathymetrical',
    'bathymetry',
    'bathyscape',
    'bathyscaph',
    'bathyscaphe',
    'bathysphere',
    'batidaceae',
    'batik',
    'bating',
    'batis',
    'batiste',
    'batman',
    'batna',
    'batoidei',
    'baton',
    'batrachia',
    'batrachian',
    'batrachoididae',
    'batrachomyomachia',
    'batrachoseps',
    'bats',
    'batsman',
    'batswana',
    'battalion',
    'batted',
    'batten',
    'batter',
    'battercake',
    'battered',
    'batteries',
    'battering',
    'batters',
    'battery',
    'batting',
    'battle',
    'battled',
    'battledore',
    'battlefield',
    'battlefront',
    'battleful',
    'battleground',
    'battlement',
    'battlemented',
    'battlements',
    'battler',
    'battles',
    'battleship',
    'battlesight',
    'battlewagon',
    'battue',
    'batty',
    'batwing',
    'bauble',
    'baud',
    'baudelaire',
    'bauhaus',
    'bauhinia',
    'baulk',
    'baulker',
    'baum',
    'bauxite',
    'bauxitic',
    'bavaria',
    'bavarian',
    'bawbee',
    'bawd',
    'bawdiness',
    'bawdry',
    'bawdy',
    'bawdyhouse',
    'bawl',
    'bawled',
    'bawler',
    'bawling',
    'bay',
    'baya',
    'bayard',
    'bayat',
    'bayberry',
    'baycol',
    'bayer',
    'bayes',
    'bayesian',
    'baykal',
    'bayonet',
    'bayonets',
    'bayonne',
    'bayou',
    'bayous',
    'bayrut',
    'bays',
    'bazaar',
    'bazar',
    'bazillion',
    'bazooka',
    'bb',
    'bbc',
    'bbl',
    'bbq',
    'bbs',
    'bc',
    'bcb',
    'bcbc',
    'bcbd',
    'bce',
    'bd',
    'bdellium',
    'be',
    'beach',
    'beachball',
    'beachcomber',
    'beached',
    'beaches',
    'beachfront',
    'beachhead',
    'beachwear',
    'beacon',
    'beacons',
    'bead',
    'beaded',
    'beading',
    'beadle',
    'beadlike',
    'beads',
    'beadsman',
    'beadwork',
    'beady',
    'beagle',
    'beagles',
    'beagling',
    'beak',
    'beaked',
    'beaker',
    'beakless',
    'beaklike',
    'beaks',
    'beam',
    'beamed',
    'beaming',
    'beamish',
    'beams',
    'beamy',
    'bean',
    'beanbag',
    'beanball',
    'beaner',
    'beanfeast',
    'beanie',
    'beano',
    'beans',
    'beanstalk',
    'beantown',
    'beany',
    'bear',
    'bearable',
    'bearberry',
    'bearcat',
    'beard',
    'bearded',
    'beardless',
    'beardown',
    'beards',
    'bearer',
    'bearers',
    'bearing',
    'bearings',
    'bearish',
    'bearnaise',
    'bears',
    'bearskin',
    'bearwood',
    'beast',
    'beastliness',
    'beastly',
    'beasts',
    'beat',
    'beatable',
    'beaten',
    'beater',
    'beaters',
    'beatific',
    'beatification',
    'beatified',
    'beatify',
    'beating',
    'beatings',
    'beatitude',
    'beatles',
    'beatnik',
    'beatniks',
    'beatrice',
    'beats',
    'beatty',
    'beau',
    'beaufort',
    'beaugregory',
    'beaujolais',
    'beaumont',
    'beaumontia',
    'beaut',
    'beauteous',
    'beauteousness',
    'beautician',
    'beauticians',
    'beauties',
    'beautification',
    'beautifies',
    'beautiful',
    'beautifully',
    'beautify',
    'beautifying',
    'beauty',
    'beauvoir',
    'beaver',
    'beaverbrook',
    'beavers',
    'bebop',
    'becalm',
    'becalmed',
    'became',
    'because',
    'bechamel',
    'bechance',
    'becharm',
    'bechuana',
    'beck',
    'becker',
    'becket',
    'beckett',
    'beckley',
    'beckon',
    'beckoning',
    'becloud',
    'become',
    'becomes',
    'becoming',
    'becomingness',
    'becquerel',
    'bed',
    'beda',
    'bedamn',
    'bedaub',
    'bedaubed',
    'bedaze',
    'bedazzle',
    'bedbug',
    'bedbugs',
    'bedchamber',
    'bedclothes',
    'bedcover',
    'bedcovers',
    'bedded',
    'bedder',
    'bedding',
    'bede',
    'bedeck',
    'bedesman',
    'bedevil',
    'bedevilment',
    'bedew',
    'bedewed',
    'bedfast',
    'bedfellow',
    'bedframe',
    'bedground',
    'bedhop',
    'bedight',
    'bedim',
    'bedimmed',
    'bedizen',
    'bedlam',
    'bedlamite',
    'bedless',
    'bedouin',
    'bedpan',
    'bedpost',
    'bedraggle',
    'bedraggled',
    'bedrest',
    'bedrid',
    'bedridden',
    'bedrock',
    'bedroll',
    'bedroom',
    'bedrooms',
    'beds',
    'bedside',
    'bedsit',
    'bedsitter',
    'bedsore',
    'bedspread',
    'bedspreads',
    'bedspring',
    'bedstead',
    'bedstraw',
    'bedstraws',
    'bedtime',
    'beduin',
    'bedwetter',
    'bee',
    'beebalm',
    'beebread',
    'beech',
    'beechen',
    'beecher',
    'beeches',
    'beechnut',
    'beechnuts',
    'beechwood',
    'beef',
    'beefalo',
    'beefburger',
    'beefcake',
    'beefeater',
    'beefsteak',
    'beefwood',
    'beefy',
    'beehive',
    'beehives',
    'beekeeper',
    'beekeeping',
    'beeline',
    'beelzebub',
    'been',
    'beep',
    'beeper',
    'beeps',
    'beer',
    'beerbohm',
    'beers',
    'beery',
    'bees',
    'beeswax',
    'beeswaxed',
    'beet',
    'beethoven',
    'beethovenian',
    'beetle',
    'beetled',
    'beetles',
    'beetleweed',
    'beetling',
    'beetroot',
    'beets',
    'befall',
    'befit',
    'befitting',
    'befog',
    'befogged',
    'befool',
    'befooling',
    'before',
    'beforehand',
    'befoul',
    'befouled',
    'befoulment',
    'befriend',
    'befriended',
    'befuddle',
    'befuddled',
    'befuddlement',
    'beg',
    'began',
    'beget',
    'begets',
    'begetter',
    'beggar',
    'beggarly',
    'beggarman',
    'beggars',
    'beggarweed',
    'beggarwoman',
    'beggary',
    'begging',
    'begild',
    'begin',
    'beginner',
    'beginners',
    'beginning',
    'begins',
    'begonia',
    'begoniaceae',
    'begonias',
    'begot',
    'begotten',
    'begrime',
    'begrimed',
    'begrudge',
    'beguile',
    'beguiled',
    'beguilement',
    'beguiler',
    'beguiling',
    'beguine',
    'begum',
    'begun',
    'behalf',
    'behave',
    'behaved',
    'behaves',
    'behaving',
    'behavior',
    'behavioral',
    'behaviorism',
    'behaviorist',
    'behavioristic',
    'behaviors',
    'behaviour',
    'behavioural',
    'behaviourism',
    'behaviourist',
    'behaviouristic',
    'behead',
    'beheaded',
    'beheading',
    'beheads',
    'behemoth',
    'behest',
    'behind',
    'behindhand',
    'behmen',
    'behmenism',
    'behold',
    'beholder',
    'beholders',
    'beholding',
    'behoove',
    'behooves',
    'behove',
    'behrens',
    'behring',
    'beige',
    'beigel',
    'beignet',
    'beijing',
    'being',
    'beingness',
    'beings',
    'beira',
    'beirut',
    'bejewel',
    'bel',
    'belabor',
    'belabored',
    'belabour',
    'belamcanda',
    'belarus',
    'belarusian',
    'belated',
    'belau',
    'belay',
    'belch',
    'belching',
    'beldam',
    'beldame',
    'beleaguer',
    'beleaguering',
    'belem',
    'belemnite',
    'belemnites',
    'belemnitic',
    'belemnitidae',
    'belemnoidea',
    'belfast',
    'belfry',
    'belgian',
    'belgique',
    'belgium',
    'belgrade',
    'belie',
    'belied',
    'belief',
    'beliefs',
    'believability',
    'believable',
    'believe',
    'believed',
    'believer',
    'believers',
    'believes',
    'believing',
    'belisarius',
    'belittle',
    'belittled',
    'belittles',
    'belittling',
    'belize',
    'bell',
    'belladonna',
    'bellarmine',
    'bellarmino',
    'bellbird',
    'bellbirds',
    'bellbottom',
    'bellboy',
    'bellboys',
    'belle',
    'bellerophon',
    'belletristic',
    'bellflower',
    'bellflowers',
    'bellhop',
    'bellicose',
    'bellicoseness',
    'bellicosity',
    'bellied',
    'bellies',
    'belligerence',
    'belligerency',
    'belligerent',
    'belling',
    'bellingham',
    'bellini',
    'bellis',
    'bellman',
    'belloc',
    'bellow',
    'bellower',
    'bellowing',
    'bellows',
    'bellpull',
    'bells',
    'bellwether',
    'bellwort',
    'belly',
    'bellyache',
    'bellyacher',
    'bellyband',
    'bellybutton',
    'bellyful',
    'bellying',
    'bellylaugh',
    'bellyless',
    'belmont',
    'belo',
    'belong',
    'belonged',
    'belonging',
    'belongings',
    'belongs',
    'belonidae',
    'belorussia',
    'belorussian',
    'belostomatidae',
    'beloved',
    'below',
    'belowground',
    'belsen',
    'belshazzar',
    'belt',
    'belted',
    'belting',
    'beltless',
    'beltlike',
    'belts',
    'beltway',
    'beluga',
    'belvedere',
    'bema',
    'bemidji',
    'bemire',
    'bemisia',
    'bemoan',
    'bemock',
    'bemuse',
    'bemused',
    'bemusement',
    'ben',
    'benadryl',
    'bench',
    'benches',
    'benchley',
    'benchmark',
    'bend',
    'bendability',
    'bendable',
    'benday',
    'bended',
    'bender',
    'bending',
    'bendopa',
    'bends',
    'beneath',
    'benedick',
    'benedict',
    'benedictine',
    'benedictines',
    'benediction',
    'benedictive',
    'benedictory',
    'benefact',
    'benefacted',
    'benefaction',
    'benefactor',
    'benefactress',
    'benefic',
    'benefice',
    'beneficed',
    'beneficence',
    'beneficent',
    'beneficial',
    'beneficiaries',
    'beneficiary',
    'beneficiate',
    'beneficiation',
    'benefit',
    'benefited',
    'benefiting',
    'benefits',
    'benelux',
    'benet',
    'benevolence',
    'benevolent',
    'benficiate',
    'bengal',
    'bengali',
    'benghazi',
    'benight',
    'benighted',
    'benign',
    'benignancy',
    'benignant',
    'benignity',
    'benin',
    'beninese',
    'benison',
    'benjamin',
    'benne',
    'bennet',
    'bennett',
    'bennettitaceae',
    'bennettitales',
    'bennettitis',
    'benni',
    'bennie',
    'bennington',
    'benniseed',
    'benny',
    'bent',
    'benthal',
    'bentham',
    'benthic',
    'benthonic',
    'benthos',
    'benton',
    'bentonite',
    'bentonitic',
    'bentwood',
    'benumb',
    'benumbed',
    'benweed',
    'benzedrine',
    'benzene',
    'benzenoid',
    'benzine',
    'benzoate',
    'benzocaine',
    'benzodiazepine',
    'benzofuran',
    'benzoic',
    'benzoin',
    'benzol',
    'benzoquinone',
    'benzyl',
    'benzylic',
    'benzylpenicillin',
    'beograd',
    'beowulf',
    'beplaster',
    'beplastered',
    'bequeath',
    'bequeathed',
    'bequest',
    'berate',
    'berating',
    'berber',
    'berberidaceae',
    'berberis',
    'berbers',
    'berceuse',
    'bercy',
    'bereave',
    'bereaved',
    'bereavement',
    'bereft',
    'beret',
    'berg',
    'bergall',
    'bergamot',
    'bergen',
    'bergenia',
    'bergerac',
    'bergman',
    'bergson',
    'beria',
    'beriberi',
    'bering',
    'berit',
    'berith',
    'berk',
    'berkeley',
    'berkelium',
    'berkshire',
    'berkshires',
    'berlage',
    'berle',
    'berlin',
    'berliner',
    'berlioz',
    'berm',
    'bermuda',
    'bermudan',
    'bermudas',
    'bermudian',
    'bern',
    'bernard',
    'berne',
    'bernhardt',
    'bernini',
    'bernoulli',
    'bernstein',
    'beroe',
    'berra',
    'berretta',
    'berried',
    'berries',
    'berry',
    'berrying',
    'berrylike',
    'berserk',
    'berserker',
    'berteroa',
    'berth',
    'bertholletia',
    'berths',
    'bertie',
    'bertillon',
    'bertolt',
    'bertolucci',
    'bertrand',
    'berycomorphi',
    'beryl',
    'beryllium',
    'berzelius',
    'beseech',
    'beseeching',
    'beseem',
    'beset',
    'beshrew',
    'beside',
    'besides',
    'besiege',
    'besieged',
    'besieger',
    'besiegers',
    'besieging',
    'besmear',
    'besmirch',
    'besom',
    'besot',
    'besotted',
    'bespangle',
    'bespatter',
    'bespeak',
    'bespeckle',
    'bespectacled',
    'bespoke',
    'bespoken',
    'bespot',
    'besprent',
    'besprinkle',
    'bessel',
    'bessemer',
    'bessera',
    'besseya',
    'best',
    'bestial',
    'bestialise',
    'bestiality',
    'bestialize',
    'bestiary',
    'bestir',
    'bestirred',
    'bestow',
    'bestowal',
    'bestowed',
    'bestower',
    'bestowing',
    'bestowment',
    'bestrew',
    'bestride',
    'bestseller',
    'bestubbled',
    'bet',
    'beta',
    'betaine',
    'betatron',
    'betel',
    'betelgeuse',
    'beth',
    'bethe',
    'bethel',
    'bethink',
    'bethlehem',
    'bethought',
    'bethune',
    'betide',
    'betise',
    'betoken',
    'betray',
    'betrayal',
    'betrayed',
    'betrayer',
    'betrays',
    'betroth',
    'betrothal',
    'betrothed',
    'bets',
    'better',
    'bettered',
    'bettering',
    'betterment',
    'betters',
    'betting',
    'bettong',
    'bettongia',
    'bettor',
    'betula',
    'betulaceae',
    'betulaceous',
    'between',
    'betweenbrain',
    'bevatron',
    'bevel',
    'beveled',
    'beveling',
    'bevelled',
    'beverage',
    'beverages',
    'beveridge',
    'bevin',
    'bevy',
    'bewail',
    'bewailing',
    'beware',
    'bewhisker',
    'bewhiskered',
    'bewilder',
    'bewildered',
    'bewildering',
    'bewilderment',
    'bewitch',
    'bewitched',
    'bewitchery',
    'bewitching',
    'bewitchment',
    'bewray',
    'bextra',
    'bey',
    'beyond',
    'bezant',
    'bezel',
    'bezique',
    'bezzant',
    'bh',
    'bhadon',
    'bhadrapada',
    'bhaga',
    'bhagavadgita',
    'bhakti',
    'bhang',
    'bharat',
    'bhutan',
    'bhutanese',
    'bhutani',
    'bi',
    'bialy',
    'bialystoker',
    'biannual',
    'bias',
    'biased',
    'biasing',
    'biaural',
    'biauricular',
    'biaxal',
    'biaxate',
    'biaxial',
    'bib',
    'bibbed',
    'bible',
    'bibless',
    'biblical',
    'bibliographer',
    'bibliographic',
    'bibliographical',
    'bibliographies',
    'bibliography',
    'bibliolatrous',
    'bibliolatry',
    'bibliomania',
    'bibliomaniacal',
    'bibliophile',
    'bibliophiles',
    'bibliophilic',
    'bibliopole',
    'bibliopoles',
    'bibliopolic',
    'bibliopolist',
    'bibliothec',
    'bibliotheca',
    'bibliothecal',
    'bibliothecarial',
    'bibliotic',
    'bibliotics',
    'bibliotist',
    'bibos',
    'bibulous',
    'bicameral',
    'bicapsular',
    'bicarbonate',
    'bicentenary',
    'bicentennial',
    'bicentric',
    'bicephalous',
    'biceps',
    'bichloride',
    'bichromate',
    'bichromated',
    'bichrome',
    'bicipital',
    'bicker',
    'bickering',
    'bicolor',
    'bicolored',
    'bicolour',
    'bicoloured',
    'biconcave',
    'biconvex',
    'bicorn',
    'bicornate',
    'bicorne',
    'bicorned',
    'bicornuate',
    'bicornuous',
    'bicuspid',
    'bicuspidate',
    'bicycle',
    'bicycler',
    'bicycles',
    'bicyclic',
    'bicycling',
    'bicyclist',
    'bicyclists',
    'bicylindrical',
    'bid',
    'bida',
    'biddable',
    'bidder',
    'bidders',
    'bidding',
    'biddy',
    'bide',
    'bidens',
    'bidentate',
    'bidet',
    'bidirectional',
    'bids',
    'biedermeier',
    'biedermeyer',
    'bien',
    'biennial',
    'biennially',
    'biennials',
    'bier',
    'bierce',
    'biface',
    'bifacial',
    'biff',
    'bifid',
    'bifida',
    'bifilar',
    'biflagellate',
    'bifocal',
    'bifocals',
    'bifoliate',
    'biform',
    'bifurcate',
    'bifurcated',
    'bifurcates',
    'bifurcating',
    'bifurcation',
    'bifurcations',
    'big',
    'bigamist',
    'bigamous',
    'bigamy',
    'bigarade',
    'bigeminal',
    'bigeneric',
    'bigeye',
    'bigfoot',
    'bigger',
    'biggest',
    'biggin',
    'biggish',
    'bighead',
    'bigheaded',
    'bighearted',
    'bigheartedness',
    'bighorn',
    'bight',
    'bigmouthed',
    'bigness',
    'bignonia',
    'bignoniaceae',
    'bignoniaceous',
    'bignoniad',
    'bigos',
    'bigot',
    'bigoted',
    'bigotry',
    'bigram',
    'bigwig',
    'bihar',
    'bihari',
    'bijou',
    'bike',
    'biker',
    'bikers',
    'bikini',
    'bilabial',
    'bilabiate',
    'bilateral',
    'bilateralism',
    'bilaterality',
    'bilaterally',
    'bilberries',
    'bilberry',
    'bilby',
    'bile',
    'bilestone',
    'bilge',
    'bilged',
    'bilges',
    'bilgewater',
    'bilgy',
    'bilharzia',
    'bilharziasis',
    'biliary',
    'bilimbi',
    'bilinear',
    'bilingual',
    'bilingualism',
    'bilingualist',
    'bilious',
    'biliousness',
    'bilirubin',
    'bilk',
    'bilked',
    'bill',
    'billabong',
    'billboard',
    'billboards',
    'billed',
    'billet',
    'billeted',
    'billfish',
    'billfold',
    'billhook',
    'billiard',
    'billiards',
    'billing',
    'billings',
    'billingsgate',
    'billion',
    'billionaire',
    'billions',
    'billionth',
    'billow',
    'billowed',
    'billowing',
    'billows',
    'billowy',
    'bills',
    'billy',
    'billyo',
    'billyoh',
    'billystick',
    'bilobate',
    'bilobated',
    'bilobed',
    'bilocation',
    'bilocular',
    'biloculate',
    'biloxi',
    'bilsted',
    'biltong',
    'bimanual',
    'bimbo',
    'bimester',
    'bimestrial',
    'bimetal',
    'bimetallic',
    'bimetallism',
    'bimetallist',
    'bimetallistic',
    'bimillenary',
    'bimillenial',
    'bimillennium',
    'bimli',
    'bimodal',
    'bimolecular',
    'bimonthly',
    'bimorphemic',
    'bimotored',
    'bin',
    'binaries',
    'binary',
    'binate',
    'binaural',
    'bind',
    'bindable',
    'binder',
    'binders',
    'bindery',
    'binding',
    'bindings',
    'binds',
    'bindweed',
    'bine',
    'binet',
    'binful',
    'bing',
    'binge',
    'binged',
    'binger',
    'binges',
    'binghamton',
    'bingle',
    'bingo',
    'binnacle',
    'binocular',
    'binoculars',
    'binomial',
    'binominal',
    'bins',
    'binturong',
    'binturongs',
    'binuclear',
    'binucleate',
    'binucleated',
    'bioarm',
    'bioassay',
    'bioattack',
    'biocatalyst',
    'biocatalysts',
    'biocatalytic',
    'biochemical',
    'biochemist',
    'biochemistry',
    'biochip',
    'bioclimatic',
    'bioclimatology',
    'biodefence',
    'biodefense',
    'biodegradable',
    'biodegrade',
    'biodiversity',
    'bioelectricity',
    'bioengineering',
    'bioethics',
    'biofeedback',
    'bioflavinoid',
    'biogenesis',
    'biogenetic',
    'biogenic',
    'biogenous',
    'biogeny',
    'biogeographic',
    'biogeographical',
    'biogeography',
    'biographer',
    'biographic',
    'biographical',
    'biographies',
    'biography',
    'biohazard',
    'bioko',
    'biologic',
    'biological',
    'biologically',
    'biologism',
    'biologist',
    'biologistic',
    'biologists',
    'biology',
    'bioluminescence',
    'bioluminescent',
    'biomass',
    'biome',
    'biomedical',
    'biomedicine',
    'biometric',
    'biometrics',
    'biometry',
    'bionic',
    'bionics',
    'bionomic',
    'bionomical',
    'bionomics',
    'biont',
    'biophysicist',
    'biophysics',
    'biopiracy',
    'biopsy',
    'bioremediation',
    'biosafety',
    'bioscience',
    'bioscope',
    'biosphere',
    'biostatistics',
    'biosynthesis',
    'biosynthetic',
    'biosystematic',
    'biosystematics',
    'biosystematy',
    'biota',
    'biotech',
    'biotechnology',
    'bioterrorism',
    'biotic',
    'biotin',
    'biotite',
    'biotitic',
    'biotype',
    'biotypic',
    'biovular',
    'bioweapon',
    'bipara',
    'biparous',
    'bipartisan',
    'bipartite',
    'bipartizan',
    'biped',
    'bipedal',
    'bipedalism',
    'bipinnate',
    'bipinnatifid',
    'biplane',
    'bipolar',
    'biprism',
    'biquadrate',
    'biquadratic',
    'biracial',
    'biradial',
    'biradially',
    'biramous',
    'birch',
    'birchbark',
    'birchen',
    'birches',
    'bird',
    'birdbath',
    'birdbrain',
    'birdcage',
    'birdcall',
    'birder',
    'birdfeeder',
    'birdhouse',
    'birdie',
    'birdlime',
    'birdnest',
    'birdnesting',
    'birds',
    'birdseed',
    'birdsong',
    'birdsongs',
    'birdwatch',
    'birefringence',
    'birefringent',
    'biretta',
    'biriani',
    'birken',
    'birl',
    'birle',
    'birling',
    'birmingham',
    'biro',
    'birr',
    'birretta',
    'birth',
    'birthday',
    'birthing',
    'birthmark',
    'birthmarks',
    'birthplace',
    'birthrate',
    'birthright',
    'birthroot',
    'births',
    'birthwort',
    'birthworts',
    'biryani',
    'bisayan',
    'bisayas',
    'biscay',
    'biscayne',
    'biscuit',
    'biscuits',
    'biscutella',
    'bise',
    'bisect',
    'bisection',
    'bisectional',
    'bisects',
    'biserrate',
    'bisexual',
    'bisexuality',
    'bishkek',
    'bishop',
    'bishopric',
    'bishopry',
    'bishops',
    'biskek',
    'bismarck',
    'bismarckian',
    'bismark',
    'bismuth',
    'bismuthal',
    'bismuthic',
    'bison',
    'bisontine',
    'bisque',
    'bissau',
    'bister',
    'bistered',
    'bistre',
    'bistred',
    'bistro',
    'bistroic',
    'bisulcate',
    'bit',
    'bitartrate',
    'bitch',
    'bitchery',
    'bitchiness',
    'bitchy',
    'bite',
    'biteplate',
    'biter',
    'bites',
    'bitewing',
    'bithynia',
    'biting',
    'bitis',
    'bitmap',
    'bitok',
    'bits',
    'bitstock',
    'bitt',
    'bittacidae',
    'bitten',
    'bitter',
    'bittercress',
    'bitterish',
    'bitterly',
    'bittern',
    'bitterness',
    'bitterns',
    'bitternut',
    'bitterroot',
    'bitters',
    'bittersweet',
    'bitterweed',
    'bitterwood',
    'bitthead',
    'bittie',
    'bitts',
    'bitty',
    'bitumastic',
    'bitumen',
    'bitumenoid',
    'bitumens',
    'bituminise',
    'bituminize',
    'bituminoid',
    'bituminous',
    'bivalent',
    'bivalve',
    'bivalved',
    'bivalves',
    'bivalvia',
    'bivariate',
    'bivouac',
    'bivouacking',
    'biweekly',
    'biyearly',
    'biz',
    'bizarre',
    'bizarreness',
    'bize',
    'bizet',
    'bizonal',
    'bja',
    'bjs',
    'bk',
    'blab',
    'blabber',
    'blabbermouth',
    'blabbermouthed',
    'blabby',
    'blaberus',
    'black',
    'blackball',
    'blackbeard',
    'blackbeetle',
    'blackberries',
    'blackberry',
    'blackbird',
    'blackbirds',
    'blackboard',
    'blackboards',
    'blackbody',
    'blackbuck',
    'blackbucks',
    'blackburn',
    'blackcap',
    'blackcock',
    'blackdamp',
    'blacked',
    'blacken',
    'blackened',
    'blackening',
    'blackest',
    'blackface',
    'blackfish',
    'blackflies',
    'blackfly',
    'blackfoot',
    'blackfriar',
    'blackguard',
    'blackguardly',
    'blackhead',
    'blackheart',
    'blacking',
    'blackish',
    'blackjack',
    'blacklead',
    'blackleg',
    'blacklist',
    'blacklisted',
    'blackmail',
    'blackmailer',
    'blackness',
    'blackout',
    'blackpoll',
    'blackpool',
    'blacks',
    'blacksburg',
    'blackseed',
    'blackshirt',
    'blacksmith',
    'blacksnake',
    'blacksnakes',
    'blacktail',
    'blackthorn',
    'blacktop',
    'blacktopping',
    'blackwash',
    'blackwater',
    'blackwood',
    'bladder',
    'bladderlike',
    'bladdernose',
    'bladderpod',
    'bladderpods',
    'bladders',
    'bladderwort',
    'bladderwrack',
    'bladdery',
    'blade',
    'bladed',
    'bladelike',
    'blades',
    'blae',
    'blaeberry',
    'blah',
    'blahs',
    'blain',
    'blair',
    'blake',
    'blamable',
    'blame',
    'blameable',
    'blamed',
    'blameful',
    'blameless',
    'blamelessness',
    'blames',
    'blameworthiness',
    'blameworthy',
    'blaming',
    'blanc',
    'blanch',
    'blanched',
    'blancmange',
    'bland',
    'blandfordia',
    'blandish',
    'blandishment',
    'blandness',
    'blank',
    'blanked',
    'blanket',
    'blanketed',
    'blankets',
    'blankness',
    'blanks',
    'blanquillo',
    'blanshard',
    'blantyre',
    'blare',
    'blarina',
    'blaring',
    'blarney',
    'blase',
    'blaspheme',
    'blasphemer',
    'blasphemous',
    'blasphemy',
    'blast',
    'blasted',
    'blastema',
    'blastemal',
    'blastemata',
    'blastematic',
    'blastemic',
    'blaster',
    'blasting',
    'blastocele',
    'blastocladia',
    'blastocladiales',
    'blastocoel',
    'blastocoele',
    'blastocoelic',
    'blastocyst',
    'blastocyte',
    'blastocytoma',
    'blastoderm',
    'blastodermatic',
    'blastodermic',
    'blastodiaceae',
    'blastodisc',
    'blastoff',
    'blastogenesis',
    'blastogenetic',
    'blastoma',
    'blastomere',
    'blastomeres',
    'blastomeric',
    'blastomyces',
    'blastomycete',
    'blastomycosis',
    'blastomycotic',
    'blastoporal',
    'blastopore',
    'blastoporic',
    'blastosphere',
    'blastospheric',
    'blastula',
    'blastular',
    'blat',
    'blatancy',
    'blatant',
    'blatantly',
    'blate',
    'blather',
    'blatherskite',
    'blatta',
    'blattaria',
    'blattella',
    'blattidae',
    'blattodea',
    'blaxploitation',
    'blaze',
    'blazed',
    'blazer',
    'blazers',
    'blazes',
    'blazing',
    'blazon',
    'blazonry',
    'bleach',
    'bleached',
    'bleacher',
    'bleachers',
    'bleaches',
    'bleaching',
    'bleak',
    'bleakness',
    'blear',
    'bleary',
    'bleat',
    'bleb',
    'blebbed',
    'blebby',
    'blechnaceae',
    'blechnum',
    'bled',
    'bleed',
    'bleeder',
    'bleeding',
    'bleep',
    'bleeped',
    'blemish',
    'blemished',
    'blench',
    'blend',
    'blende',
    'blended',
    'blender',
    'blending',
    'blends',
    'blenheim',
    'blennies',
    'blenniidae',
    'blennioid',
    'blennioidea',
    'blennius',
    'blenny',
    'blepharism',
    'blepharitis',
    'blepharospasm',
    'blephilia',
    'bleriot',
    'bless',
    'blessed',
    'blessedly',
    'blessedness',
    'blessing',
    'blessings',
    'blest',
    'blether',
    'bletia',
    'bletilla',
    'bleu',
    'blew',
    'blewits',
    'blida',
    'bligh',
    'blighia',
    'blight',
    'blighted',
    'blighter',
    'blighty',
    'blimp',
    'blimpish',
    'blind',
    'blinded',
    'blinder',
    'blinders',
    'blindfold',
    'blindfolded',
    'blinding',
    'blindly',
    'blindness',
    'blinds',
    'blindside',
    'blindsided',
    'blindworm',
    'blindworms',
    'bling',
    'blini',
    'blink',
    'blinker',
    'blinking',
    'blinks',
    'blintz',
    'blintze',
    'bliny',
    'blip',
    'bliss',
    'blissful',
    'blissfulness',
    'blissus',
    'blister',
    'blistered',
    'blistering',
    'blisters',
    'blistery',
    'blithe',
    'blitheness',
    'blither',
    'blithesome',
    'blitt',
    'blitz',
    'blitzed',
    'blitzkrieg',
    'blitzstein',
    'blixen',
    'blizzard',
    'bloat',
    'bloated',
    'bloater',
    'bloating',
    'blob',
    'bloc',
    'blocadren',
    'bloch',
    'block',
    'blockade',
    'blockaded',
    'blockading',
    'blockage',
    'blockbuster',
    'blocked',
    'blocker',
    'blockers',
    'blockhead',
    'blockheaded',
    'blockhouse',
    'blocking',
    'blockish',
    'blocks',
    'blocky',
    'blocs',
    'bloemfontein',
    'blog',
    'blogger',
    'blok',
    'bloke',
    'blolly',
    'blond',
    'blonde',
    'blondness',
    'blood',
    'bloodbath',
    'bloodberry',
    'bloodcurdling',
    'blooded',
    'bloodguilt',
    'bloodguilty',
    'bloodhound',
    'bloodiest',
    'bloodiness',
    'bloodleaf',
    'bloodless',
    'bloodletting',
    'bloodline',
    'bloodlust',
    'bloodmobile',
    'bloodroot',
    'bloodshed',
    'bloodshot',
    'bloodstain',
    'bloodstained',
    'bloodstock',
    'bloodstone',
    'bloodstream',
    'bloodsucker',
    'bloodsucking',
    'bloodthirstiness',
    'bloodthirsty',
    'bloodworm',
    'bloodwort',
    'bloody',
    'bloom',
    'bloomer',
    'bloomeria',
    'bloomers',
    'bloomfield',
    'blooming',
    'bloomington',
    'blooms',
    'bloomsbury',
    'blooper',
    'blossom',
    'blossomed',
    'blossoming',
    'blossoms',
    'blot',
    'blotch',
    'blotched',
    'blotches',
    'blotchy',
    'blots',
    'blotter',
    'blotting',
    'blotto',
    'blouse',
    'bloviate',
    'blow',
    'blowback',
    'blowball',
    'blower',
    'blowfish',
    'blowflies',
    'blowfly',
    'blowgun',
    'blowhard',
    'blowhole',
    'blowing',
    'blowjob',
    'blowlamp',
    'blown',
    'blowout',
    'blowpipe',
    'blows',
    'blowsy',
    'blowtorch',
    'blowtube',
    'blowup',
    'blowy',
    'blowzy',
    'blt',
    'blub',
    'blubber',
    'blubberer',
    'blubbery',
    'blucher',
    'bludgeon',
    'bludgeoned',
    'bludgeoner',
    'blue',
    'bluebeard',
    'bluebell',
    'blueberries',
    'blueberry',
    'bluebill',
    'bluebird',
    'bluebirds',
    'bluebonnet',
    'bluebottle',
    'bluecoat',
    'bluefin',
    'bluefish',
    'bluegill',
    'bluegrass',
    'bluehead',
    'blueing',
    'blueish',
    'bluejacket',
    'blueness',
    'bluenose',
    'bluepoint',
    'blueprint',
    'blueprints',
    'blues',
    'bluestem',
    'bluestocking',
    'bluestone',
    'bluethroat',
    'bluetick',
    'bluetongue',
    'blueweed',
    'bluewing',
    'bluff',
    'bluffer',
    'bluffing',
    'bluffness',
    'bluffs',
    'bluing',
    'bluish',
    'blunder',
    'blunderbuss',
    'blundered',
    'blunderer',
    'blunt',
    'blunted',
    'bluntly',
    'bluntness',
    'blur',
    'blurb',
    'blurbs',
    'blurred',
    'blurriness',
    'blurry',
    'blurs',
    'blurt',
    'blurted',
    'blush',
    'blushed',
    'blusher',
    'blushful',
    'blushing',
    'bluster',
    'blustered',
    'blusterer',
    'blustering',
    'blusterous',
    'blustery',
    'bm',
    'bmdo',
    'bmi',
    'bmr',
    'bmus',
    'bns',
    'bo',
    'boa',
    'boann',
    'boar',
    'board',
    'boarder',
    'boarding',
    'boardinghouse',
    'boardroom',
    'boards',
    'boardwalk',
    'boarfish',
    'boarfishes',
    'boarhound',
    'boars',
    'boas',
    'boast',
    'boaster',
    'boastful',
    'boastfulness',
    'boasting',
    'boat',
    'boatbill',
    'boatbills',
    'boatbuilder',
    'boater',
    'boaters',
    'boathouse',
    'boating',
    'boatload',
    'boatman',
    'boatmanship',
    'boatmen',
    'boats',
    'boatswain',
    'boatyard',
    'bob',
    'bobbed',
    'bobber',
    'bobbin',
    'bobble',
    'bobby',
    'bobbysock',
    'bobbysocks',
    'bobbysoxer',
    'bobcat',
    'bobfloat',
    'bobolink',
    'bobolinks',
    'bobs',
    'bobsled',
    'bobsledding',
    'bobsleigh',
    'bobtail',
    'bobtailed',
    'bobwhite',
    'bobwhites',
    'boccaccio',
    'bocce',
    'bocci',
    'boccie',
    'bocconia',
    'boche',
    'bock',
    'bod',
    'bodacious',
    'boddhisatva',
    'bode',
    'bodega',
    'bodensee',
    'bodge',
    'bodhisattva',
    'bodice',
    'bodied',
    'bodies',
    'bodiless',
    'bodily',
    'boding',
    'bodkin',
    'bodoni',
    'body',
    'bodybuilder',
    'bodybuilding',
    'bodyguard',
    'bodyless',
    'bodypaint',
    'bodywork',
    'boehm',
    'boehme',
    'boehmenism',
    'boehmeria',
    'boell',
    'boeotia',
    'boeotian',
    'boer',
    'boers',
    'boethius',
    'boeuf',
    'boffin',
    'boffo',
    'bog',
    'bogart',
    'bogartian',
    'bogbean',
    'bogbeans',
    'bogey',
    'bogeyman',
    'bogged',
    'boggle',
    'boggles',
    'boggy',
    'bogie',
    'bogmat',
    'bogota',
    'bogs',
    'bogus',
    'bogy',
    'bohemia',
    'bohemian',
    'bohemianism',
    'bohme',
    'bohr',
    'bohrium',
    'boidae',
    'boil',
    'boiled',
    'boiler',
    'boilerplate',
    'boilers',
    'boilersuit',
    'boiling',
    'boils',
    'boise',
    'boisei',
    'boisterous',
    'boisterously',
    'boisterousness',
    'bokkos',
    'bokmaal',
    'bokmal',
    'bola',
    'bolanci',
    'bolbitis',
    'bold',
    'boldface',
    'boldly',
    'boldness',
    'bole',
    'bolero',
    'boletaceae',
    'bolete',
    'boletellus',
    'boletes',
    'boletus',
    'boleyn',
    'bolide',
    'bolingbroke',
    'bolivar',
    'bolivia',
    'bolivian',
    'boliviano',
    'boll',
    'bollard',
    'bollix',
    'bollock',
    'bollocks',
    'bolls',
    'bollworm',
    'bollworms',
    'bollywood',
    'bolo',
    'bologna',
    'bologram',
    'bolograph',
    'bolographic',
    'bolometer',
    'bolometric',
    'boloney',
    'bolshevik',
    'bolsheviks',
    'bolshevise',
    'bolshevism',
    'bolshevist',
    'bolshevistic',
    'bolshevize',
    'bolshie',
    'bolshy',
    'bolster',
    'bolt',
    'bolted',
    'bolti',
    'bolting',
    'boltonia',
    'bolts',
    'boltzmann',
    'bolus',
    'bolyn',
    'bolzano',
    'bomarea',
    'bomb',
    'bombacaceae',
    'bombard',
    'bombarded',
    'bombardier',
    'bombarding',
    'bombardment',
    'bombardon',
    'bombast',
    'bombastic',
    'bombax',
    'bombay',
    'bombazine',
    'bombed',
    'bomber',
    'bombers',
    'bombie',
    'bombilate',
    'bombilation',
    'bombina',
    'bombinate',
    'bombination',
    'bombing',
    'bombings',
    'bomblet',
    'bomblets',
    'bombproof',
    'bombs',
    'bombshell',
    'bombsight',
    'bombus',
    'bombycid',
    'bombycidae',
    'bombycilla',
    'bombycillidae',
    'bombyliidae',
    'bombyx',
    'bona',
    'bonaire',
    'bonanza',
    'bonaparte',
    'bonasa',
    'bonavist',
    'bonbon',
    'bonce',
    'bond',
    'bondable',
    'bondage',
    'bonded',
    'bonderise',
    'bonderize',
    'bondholder',
    'bondholders',
    'bonding',
    'bondmaid',
    'bondman',
    'bonds',
    'bondsman',
    'bondswoman',
    'bonduc',
    'bondwoman',
    'bone',
    'boned',
    'bonefish',
    'bonehead',
    'boneheaded',
    'boneless',
    'bonelet',
    'bonelike',
    'bonemeal',
    'boner',
    'bones',
    'boneset',
    'bonesetter',
    'boneshaker',
    'bonete',
    'boney',
    'bonfire',
    'bong',
    'bongo',
    'bonheur',
    'bonhoeffer',
    'bonhomie',
    'boniface',
    'boniness',
    'bonito',
    'bonitos',
    'bonk',
    'bonkers',
    'bonn',
    'bonnet',
    'bonnethead',
    'bonney',
    'bonnie',
    'bonny',
    'bonobo',
    'bonsai',
    'bontemps',
    'bonus',
    'bonxie',
    'bony',
    'bonyness',
    'bonytongues',
    'bonzer',
    'boo',
    'boob',
    'boobies',
    'booboisie',
    'boobs',
    'booby',
    'boodle',
    'booger',
    'boogeyman',
    'boogie',
    'book',
    'bookable',
    'bookbinder',
    'bookbinders',
    'bookbindery',
    'bookbinding',
    'bookcase',
    'bookcases',
    'bookclub',
    'bookdealer',
    'booked',
    'bookend',
    'booker',
    'bookfair',
    'bookie',
    'booking',
    'bookings',
    'bookish',
    'bookishness',
    'bookkeeper',
    'bookkeeping',
    'booklet',
    'booklice',
    'booklouse',
    'booklover',
    'bookmaker',
    'bookmakers',
    'bookman',
    'bookmark',
    'bookmarker',
    'bookmobile',
    'bookplate',
    'books',
    'bookseller',
    'booksellers',
    'bookshelf',
    'bookshelves',
    'bookshop',
    'bookstall',
    'bookstore',
    'bookworm',
    'boole',
    'boolean',
    'boom',
    'boomed',
    'boomer',
    'boomerang',
    'booming',
    'booms',
    'boon',
    'boondocks',
    'boondoggle',
    'boone',
    'boor',
    'boorish',
    'boorishness',
    'boost',
    'boosted',
    'booster',
    'boot',
    'bootblack',
    'bootboys',
    'booted',
    'bootee',
    'bootes',
    'booth',
    'boothose',
    'bootie',
    'bootjack',
    'bootlace',
    'bootleg',
    'bootlegger',
    'bootleggers',
    'bootlegging',
    'bootless',
    'bootlick',
    'bootlicker',
    'bootlicking',
    'bootmaker',
    'boots',
    'bootstrap',
    'booty',
    'booyong',
    'booze',
    'boozer',
    'boozing',
    'boozy',
    'bop',
    'bopeep',
    'boracic',
    'borage',
    'boraginaceae',
    'borago',
    'borassus',
    'borate',
    'borated',
    'borax',
    'bordeaux',
    'bordelaise',
    'bordello',
    'border',
    'bordered',
    'borderer',
    'bordering',
    'borderland',
    'borderlands',
    'borderline',
    'borders',
    'bore',
    'boreal',
    'borealis',
    'boreas',
    'borecole',
    'bored',
    'boredom',
    'borer',
    'borers',
    'bores',
    'borges',
    'borgia',
    'boric',
    'boring',
    'boringly',
    'boringness',
    'born',
    'borne',
    'bornean',
    'borneo',
    'bornite',
    'borodin',
    'borodino',
    'boron',
    'boronic',
    'borosilicate',
    'borough',
    'boroughs',
    'borrelia',
    'borrow',
    'borrowed',
    'borrower',
    'borrowers',
    'borrowing',
    'borrows',
    'borsch',
    'borscht',
    'borsh',
    'borshch',
    'borsht',
    'borstal',
    'bortsch',
    'borzoi',
    'bos',
    'bosc',
    'bosch',
    'bose',
    'boselaphus',
    'bosh',
    'bosie',
    'bosk',
    'boskop',
    'boskopoid',
    'bosky',
    'bosnia',
    'bosnian',
    'bosom',
    'bosomed',
    'bosomy',
    'boson',
    'bosons',
    'bosporus',
    'boss',
    'bosses',
    'bossism',
    'bossy',
    'boston',
    'bostonian',
    'bosun',
    'boswell',
    'boswellia',
    'bosworth',
    'bot',
    'bota',
    'botanic',
    'botanical',
    'botanise',
    'botanist',
    'botanize',
    'botany',
    'botaurus',
    'botch',
    'botched',
    'botcher',
    'botchy',
    'botflies',
    'botfly',
    'both',
    'bother',
    'botheration',
    'bothered',
    'bothering',
    'bothers',
    'bothersome',
    'bothidae',
    'bothnia',
    'bothrops',
    'botonee',
    'botonnee',
    'botox',
    'botrychium',
    'botryoid',
    'botryoidal',
    'botswana',
    'botswanan',
    'botticelli',
    'bottle',
    'bottlebrush',
    'bottlecap',
    'bottled',
    'bottlefeed',
    'bottleful',
    'bottleneck',
    'bottlenecked',
    'bottlenose',
    'bottler',
    'bottles',
    'bottom',
    'bottomed',
    'bottomland',
    'bottomlands',
    'bottomless',
    'bottomlessness',
    'bottommost',
    'bottoms',
    'botuliform',
    'botulin',
    'botulinal',
    'botulinum',
    'botulinus',
    'botulism',
    'botulismotoxin',
    'bouchee',
    'boucle',
    'boudoir',
    'bouffant',
    'bouffe',
    'bougainvillaea',
    'bougainville',
    'bougainvillea',
    'bough',
    'boughed',
    'boughless',
    'boughs',
    'bought',
    'boughten',
    'bouillabaisse',
    'bouillon',
    'boulder',
    'bouldered',
    'boulders',
    'bouldery',
    'boule',
    'boulevard',
    'boulevardier',
    'boulez',
    'boulle',
    'bounce',
    'bounced',
    'bouncer',
    'bounces',
    'bounciness',
    'bouncing',
    'bouncy',
    'bound',
    'boundaries',
    'boundary',
    'bounded',
    'boundedness',
    'bounden',
    'bounder',
    'bounderish',
    'bounding',
    'boundless',
    'boundlessly',
    'boundlessness',
    'bounds',
    'bounteous',
    'bounteousness',
    'bountied',
    'bountiful',
    'bountifulness',
    'bounty',
    'bouquet',
    'bouquets',
    'bourbon',
    'bourbons',
    'bourdon',
    'bourgeois',
    'bourgeoisie',
    'bourgeon',
    'bourgogne',
    'bourguignon',
    'bourn',
    'bourne',
    'bourse',
    'bourtree',
    'bouse',
    'boustrophedon',
    'boustrophedonic',
    'bout',
    'bouteloua',
    'boutique',
    'boutonniere',
    'bouts',
    'bouvet',
    'bouvines',
    'bouyei',
    'bovid',
    'bovidae',
    'bovids',
    'bovinae',
    'bovine',
    'bovines',
    'bovini',
    'bovril',
    'bow',
    'bowditch',
    'bowdler',
    'bowdlerisation',
    'bowdlerise',
    'bowdleriser',
    'bowdlerism',
    'bowdlerization',
    'bowdlerize',
    'bowdlerized',
    'bowdlerizer',
    'bowed',
    'bowel',
    'bowelless',
    'bowels',
    'bower',
    'bowerbird',
    'bowerbirds',
    'bowers',
    'bowery',
    'bowfin',
    'bowfins',
    'bowfront',
    'bowhead',
    'bowie',
    'bowiea',
    'bowing',
    'bowknot',
    'bowl',
    'bowlder',
    'bowled',
    'bowleg',
    'bowlegged',
    'bowler',
    'bowlful',
    'bowline',
    'bowling',
    'bowls',
    'bowman',
    'bows',
    'bowse',
    'bowsprit',
    'bowstring',
    'bowtie',
    'box',
    'boxberry',
    'boxcar',
    'boxcars',
    'boxed',
    'boxer',
    'boxers',
    'boxershorts',
    'boxes',
    'boxfish',
    'boxfishes',
    'boxful',
    'boxing',
    'boxlike',
    'boxthorn',
    'boxwood',
    'boxy',
    'boy',
    'boycott',
    'boyd',
    'boyfriend',
    'boyhood',
    'boyish',
    'boyishness',
    'boykinia',
    'boyle',
    'boylike',
    'boyne',
    'boys',
    'boysenberry',
    'boytrose',
    'bozeman',
    'bozo',
    'bph',
    'bpi',
    'bpm',
    'bps',
    'br',
    'bra',
    'brabble',
    'brace',
    'braced',
    'bracelet',
    'bracelets',
    'bracer',
    'bracero',
    'braces',
    'brachial',
    'brachiate',
    'brachiation',
    'brachinus',
    'brachiocephalic',
    'brachiopod',
    'brachiopoda',
    'brachiopodous',
    'brachiopods',
    'brachium',
    'brachycephalic',
    'brachycephalism',
    'brachycephaly',
    'brachychiton',
    'brachycome',
    'brachycranial',
    'brachycranic',
    'brachydactylia',
    'brachydactylic',
    'brachydactylous',
    'brachydactyly',
    'brachypterous',
    'brachystegia',
    'brachyura',
    'brachyuran',
    'brachyurous',
    'bracing',
    'bracken',
    'bracket',
    'bracketed',
    'brackets',
    'brackish',
    'brackishness',
    'bract',
    'bracteal',
    'bracteate',
    'bracted',
    'bracteolate',
    'bracteole',
    'bracteoles',
    'bractlet',
    'bracts',
    'brad',
    'bradawl',
    'bradbury',
    'bradford',
    'bradley',
    'brads',
    'bradstreet',
    'brady',
    'bradycardia',
    'bradypodidae',
    'bradypus',
    'brae',
    'brag',
    'braga',
    'brage',
    'bragg',
    'braggadocio',
    'braggart',
    'bragged',
    'bragger',
    'bragging',
    'braggy',
    'bragi',
    'brahe',
    'brahma',
    'brahman',
    'brahmana',
    'brahmanas',
    'brahmanism',
    'brahmans',
    'brahmaputra',
    'brahmi',
    'brahmin',
    'brahminic',
    'brahminical',
    'brahminism',
    'brahmins',
    'brahms',
    'brahui',
    'braid',
    'braided',
    'braiding',
    'braids',
    'brail',
    'braille',
    'brails',
    'brain',
    'braincase',
    'brainchild',
    'brainiac',
    'brainish',
    'brainless',
    'brainpan',
    'brainpower',
    'brains',
    'brainsick',
    'brainstem',
    'brainstorm',
    'brainstorming',
    'brainwash',
    'brainwashed',
    'brainwashing',
    'brainwave',
    'brainworker',
    'brainy',
    'braise',
    'braised',
    'braising',
    'brake',
    'brakeman',
    'brakes',
    'braking',
    'braky',
    'braless',
    'bram',
    'brama',
    'bramante',
    'bramble',
    'brambles',
    'brambling',
    'brambly',
    'bramidae',
    'bran',
    'branch',
    'branched',
    'branches',
    'branchia',
    'branchial',
    'branchiate',
    'branching',
    'branchiobdella',
    'branchiobdellidae',
    'branchiopod',
    'branchiopoda',
    'branchiopodan',
    'branchiopodous',
    'branchiostegidae',
    'branchiostomidae',
    'branchiura',
    'branchless',
    'branchlet',
    'branchlets',
    'branchy',
    'brancusi',
    'brand',
    'branded',
    'brandenburg',
    'branding',
    'brandish',
    'brandmark',
    'brands',
    'brandt',
    'brandy',
    'brandyball',
    'brandysnap',
    'brant',
    'branta',
    'braque',
    'brasenia',
    'brash',
    'brashness',
    'brasier',
    'brasil',
    'brasilia',
    'brasov',
    'brass',
    'brassard',
    'brassavola',
    'brassbound',
    'brasserie',
    'brassia',
    'brassica',
    'brassicaceae',
    'brassie',
    'brassiere',
    'brasslike',
    'brassy',
    'brat',
    'bratislava',
    'brattice',
    'brattish',
    'brattle',
    'brattleboro',
    'bratty',
    'bratwurst',
    'braun',
    'braunschweig',
    'bravado',
    'brave',
    'braved',
    'braveness',
    'braver',
    'bravery',
    'bravo',
    'bravura',
    'braw',
    'brawl',
    'brawler',
    'brawn',
    'brawniness',
    'brawny',
    'braxton',
    'bray',
    'braying',
    'braze',
    'brazen',
    'brazenness',
    'brazier',
    'brazil',
    'brazilian',
    'brazilwood',
    'brazing',
    'brazos',
    'brazzaville',
    'breach',
    'breached',
    'breaches',
    'bread',
    'breadbasket',
    'breadboard',
    'breadbox',
    'breadcrumb',
    'breadcrumbs',
    'breaded',
    'breadfruit',
    'breadline',
    'breadroot',
    'breads',
    'breadstick',
    'breadstuff',
    'breadth',
    'breadwinner',
    'break',
    'breakability',
    'breakable',
    'breakableness',
    'breakables',
    'breakage',
    'breakaway',
    'breakax',
    'breakaxe',
    'breakdown',
    'breakdowns',
    'breaker',
    'breakers',
    'breakfast',
    'breaking',
    'breakneck',
    'breakout',
    'breaks',
    'breakstone',
    'breakthrough',
    'breakup',
    'breakwater',
    'bream',
    'breams',
    'breast',
    'breastbone',
    'breastbones',
    'breasted',
    'breastfeed',
    'breastfeeding',
    'breastless',
    'breastpin',
    'breastplate',
    'breasts',
    'breaststroke',
    'breaststroker',
    'breastwork',
    'breath',
    'breathalyse',
    'breathalyser',
    'breathalyze',
    'breathalyzer',
    'breathe',
    'breathed',
    'breather',
    'breathes',
    'breathing',
    'breathless',
    'breathlessness',
    'breathtaking',
    'breccia',
    'brecciate',
    'brecht',
    'bred',
    'breech',
    'breechblock',
    'breechcloth',
    'breechclout',
    'breeched',
    'breeches',
    'breechloader',
    'breed',
    'breeder',
    'breeding',
    'breeds',
    'breeze',
    'breezeless',
    'breezes',
    'breeziness',
    'breezy',
    'bregma',
    'bregmatic',
    'breiz',
    'bremen',
    'bremerhaven',
    'bren',
    'brent',
    'brescia',
    'breslau',
    'brest',
    'bretagne',
    'brethren',
    'breton',
    'breuer',
    'breughel',
    'breve',
    'brevet',
    'breviary',
    'brevibloc',
    'brevicipitidae',
    'brevity',
    'brevoortia',
    'brew',
    'brewage',
    'brewed',
    'brewer',
    'breweries',
    'brewery',
    'brewing',
    'brewpub',
    'brews',
    'brezhnev',
    'briar',
    'briard',
    'briarroot',
    'briarwood',
    'briary',
    'bribable',
    'bribe',
    'briber',
    'bribery',
    'bribing',
    'brick',
    'brickbat',
    'brickellia',
    'brickfield',
    'brickkiln',
    'bricklayer',
    'bricklayers',
    'bricklaying',
    'brickle',
    'brickly',
    'bricks',
    'brickwork',
    'brickyard',
    'bricolage',
    'bricole',
    'bridal',
    'bride',
    'bridecake',
    'bridegroom',
    'brides',
    'bridesmaid',
    'bridge',
    'bridgeable',
    'bridgehead',
    'bridgeport',
    'bridges',
    'bridget',
    'bridgetown',
    'bridgework',
    'bridging',
    'bridle',
    'bridled',
    'bridoon',
    'brie',
    'brief',
    'briefcase',
    'briefed',
    'briefer',
    'briefing',
    'briefings',
    'briefless',
    'briefly',
    'briefness',
    'briefs',
    'brier',
    'brierpatch',
    'brierwood',
    'briery',
    'brig',
    'brigade',
    'brigadier',
    'brigand',
    'brigandine',
    'brigantine',
    'brigham',
    'bright',
    'brighten',
    'brightens',
    'brighter',
    'brightest',
    'brightly',
    'brightness',
    'brighton',
    'brigid',
    'brigit',
    'brihaspati',
    'brill',
    'brilliance',
    'brilliancy',
    'brilliant',
    'brilliantine',
    'brilliantly',
    'brim',
    'brimful',
    'brimfull',
    'brimless',
    'brimmed',
    'brimming',
    'brims',
    'brimstone',
    'brinded',
    'brindisi',
    'brindle',
    'brindled',
    'brine',
    'bring',
    'bringing',
    'brings',
    'brininess',
    'brinjal',
    'brink',
    'brinkmanship',
    'brinton',
    'briny',
    'brio',
    'brioche',
    'briony',
    'brioschi',
    'briquet',
    'briquette',
    'bris',
    'brisance',
    'brisant',
    'brisbane',
    'brisk',
    'brisked',
    'brisken',
    'brisket',
    'briskness',
    'brisling',
    'briss',
    'bristle',
    'bristlecone',
    'bristled',
    'bristlegrass',
    'bristlegrasses',
    'bristlelike',
    'bristles',
    'bristletail',
    'bristletails',
    'bristliness',
    'bristling',
    'bristly',
    'bristol',
    'brit',
    'britain',
    'britannic',
    'britches',
    'brith',
    'briticism',
    'british',
    'britisher',
    'britishism',
    'briton',
    'britons',
    'brits',
    'britt',
    'brittanic',
    'brittany',
    'britten',
    'brittle',
    'brittlebush',
    'brittleness',
    'brno',
    'broach',
    'broached',
    'broad',
    'broadax',
    'broadaxe',
    'broadband',
    'broadbill',
    'broadbills',
    'broadcast',
    'broadcaster',
    'broadcasting',
    'broadcasts',
    'broadcloth',
    'broaden',
    'broadening',
    'broadens',
    'broader',
    'broadleaf',
    'broadloom',
    'broadly',
    'broadness',
    'broadnosed',
    'broadsheet',
    'broadside',
    'broadsword',
    'broadtail',
    'broadway',
    'brobdingnag',
    'brobdingnagian',
    'broca',
    'brocade',
    'brocaded',
    'brocadopa',
    'broccoli',
    'brochette',
    'brochure',
    'brocket',
    'brockets',
    'brockhouse',
    'brodiaea',
    'brogan',
    'broglie',
    'brogue',
    'broider',
    'broil',
    'broiled',
    'broiler',
    'broiling',
    'broils',
    'broke',
    'broken',
    'brokenhearted',
    'brokenheartedness',
    'broker',
    'brokerage',
    'brokers',
    'brolly',
    'bromate',
    'bromberg',
    'brome',
    'bromegrass',
    'bromelia',
    'bromeliaceae',
    'bromeosin',
    'bromic',
    'bromide',
    'bromides',
    'bromidic',
    'brominate',
    'bromine',
    'bromoform',
    'bromus',
    'bronc',
    'bronchi',
    'bronchial',
    'bronchiolar',
    'bronchiole',
    'bronchioles',
    'bronchiolitis',
    'bronchitic',
    'bronchitis',
    'broncho',
    'bronchodilator',
    'bronchopneumonia',
    'bronchoscope',
    'bronchoscopic',
    'bronchospasm',
    'bronchus',
    'bronco',
    'broncobuster',
    'broncos',
    'bronte',
    'brontosaur',
    'brontosaurus',
    'bronx',
    'bronze',
    'bronzed',
    'bronzy',
    'brooch',
    'brood',
    'brooded',
    'brooder',
    'brooding',
    'broodmare',
    'broody',
    'brook',
    'brooke',
    'brooklet',
    'brooklime',
    'brooklyn',
    'brooks',
    'brookweed',
    'broom',
    'broomcorn',
    'brooms',
    'broomstick',
    'broomweed',
    'brosmius',
    'broth',
    'brothel',
    'brothels',
    'brother',
    'brotherhood',
    'brotherlike',
    'brotherly',
    'brothers',
    'brotula',
    'brotulidae',
    'brougham',
    'brought',
    'brouhaha',
    'broussonetia',
    'brow',
    'browallia',
    'browbeat',
    'brown',
    'browne',
    'browned',
    'brownian',
    'brownie',
    'brownies',
    'browning',
    'brownish',
    'brownness',
    'brownout',
    'brownshirt',
    'brownstone',
    'brownsville',
    'browntail',
    'browse',
    'browser',
    'browsers',
    'browsing',
    'bruce',
    'brucella',
    'brucellosis',
    'bruch',
    'bruchidae',
    'bruchus',
    'brucine',
    'bruckenthalia',
    'bruckner',
    'bruegel',
    'brueghel',
    'bruges',
    'brugmansia',
    'bruin',
    'bruise',
    'bruised',
    'bruiser',
    'bruises',
    'bruising',
    'bruit',
    'brule',
    'brumaire',
    'brumal',
    'brummagem',
    'brummell',
    'brummie',
    'brummy',
    'brumous',
    'brunanburh',
    'brunch',
    'brunei',
    'bruneian',
    'brunelleschi',
    'brunet',
    'brunette',
    'brunfelsia',
    'brunhild',
    'brunn',
    'brunnhilde',
    'bruno',
    'brunswick',
    'brunt',
    'brusa',
    'brush',
    'brushed',
    'brushes',
    'brushing',
    'brushlike',
    'brushup',
    'brushwood',
    'brushwork',
    'brushy',
    'brusk',
    'brusque',
    'brusqueness',
    'brussels',
    'brut',
    'brutal',
    'brutalisation',
    'brutalise',
    'brutality',
    'brutalization',
    'brutalize',
    'brutalized',
    'brutally',
    'brute',
    'brutes',
    'brutish',
    'brutus',
    'bruxelles',
    'bruxism',
    'brya',
    'bryaceae',
    'bryales',
    'bryan',
    'bryanthus',
    'brynhild',
    'bryonia',
    'bryony',
    'bryophyta',
    'bryophyte',
    'bryophytes',
    'bryophytic',
    'bryopsida',
    'bryozoa',
    'bryozoan',
    'brythonic',
    'bryum',
    'bs',
    'bsarch',
    'bse',
    'btu',
    'bubaline',
    'bubalus',
    'bubble',
    'bubbled',
    'bubblejet',
    'bubbler',
    'bubbles',
    'bubbliness',
    'bubbling',
    'bubbly',
    'buber',
    'bubo',
    'buboes',
    'bubonic',
    'bubulcus',
    'buccal',
    'buccaneer',
    'buccaneering',
    'buccinator',
    'buccinidae',
    'bucconidae',
    'buccula',
    'bucephala',
    'buceros',
    'bucerotidae',
    'buchan',
    'buchanan',
    'bucharest',
    'bucharesti',
    'buchenwald',
    'buchloe',
    'buchner',
    'buck',
    'buckaroo',
    'buckbean',
    'buckboard',
    'bucked',
    'buckeroo',
    'bucket',
    'bucketful',
    'buckets',
    'buckeye',
    'buckeyes',
    'bucking',
    'buckingham',
    'buckle',
    'buckled',
    'buckler',
    'bucklers',
    'buckles',
    'buckleya',
    'buckminster',
    'buckminsterfullerene',
    'buckram',
    'bucksaw',
    'buckshee',
    'buckshot',
    'buckskin',
    'buckskins',
    'buckthorn',
    'buckthorns',
    'bucktooth',
    'buckwheat',
    'buckwheats',
    'buckyball',
    'bucolic',
    'bucuresti',
    'bud',
    'budapest',
    'buddha',
    'buddhism',
    'buddhist',
    'buddhistic',
    'buddhists',
    'buddies',
    'budding',
    'buddleia',
    'buddy',
    'budge',
    'budgereegah',
    'budgerigar',
    'budgerygah',
    'budget',
    'budgetary',
    'budgeted',
    'budgie',
    'budorcas',
    'buds',
    'buenos',
    'buff',
    'buffalo',
    'buffaloes',
    'buffalofish',
    'buffer',
    'bufferin',
    'buffet',
    'buffeted',
    'buffeting',
    'bufflehead',
    'buffleheads',
    'buffoon',
    'buffoonery',
    'buffoonish',
    'bufo',
    'bufonidae',
    'bug',
    'bugaboo',
    'buganda',
    'bugbane',
    'bugbear',
    'bugged',
    'bugger',
    'buggery',
    'buggies',
    'bugginess',
    'buggy',
    'bugle',
    'bugler',
    'bugleweed',
    'bugloss',
    'bugologist',
    'bugology',
    'bugs',
    'buhl',
    'build',
    'builder',
    'builders',
    'building',
    'buildings',
    'builds',
    'buildup',
    'built',
    'buirdly',
    'bujumbura',
    'bukharin',
    'bulawayo',
    'bulb',
    'bulbaceous',
    'bulbar',
    'bulbed',
    'bulbil',
    'bulbils',
    'bulblet',
    'bulblets',
    'bulblike',
    'bulbous',
    'bulbs',
    'bulbul',
    'bulgaria',
    'bulgarian',
    'bulge',
    'bulged',
    'bulges',
    'bulghur',
    'bulginess',
    'bulging',
    'bulgur',
    'bulgy',
    'bulimarexia',
    'bulimia',
    'bulimic',
    'bulk',
    'bulked',
    'bulkhead',
    'bulkiness',
    'bulky',
    'bull',
    'bulla',
    'bullace',
    'bullate',
    'bullbat',
    'bullbrier',
    'bulldog',
    'bulldogging',
    'bulldoze',
    'bulldozer',
    'bulled',
    'bullet',
    'bullethead',
    'bulletin',
    'bulletproof',
    'bullets',
    'bullfight',
    'bullfighter',
    'bullfighting',
    'bullfights',
    'bullfinch',
    'bullfinches',
    'bullfrog',
    'bullhead',
    'bullheaded',
    'bullheadedness',
    'bullhorn',
    'bullied',
    'bullies',
    'bullion',
    'bullish',
    'bullnecked',
    'bullnose',
    'bullock',
    'bullocky',
    'bullpen',
    'bullring',
    'bullrush',
    'bulls',
    'bullshit',
    'bullshot',
    'bullterrier',
    'bully',
    'bullyboy',
    'bullying',
    'bullyrag',
    'bulnesia',
    'bulrush',
    'bultmann',
    'bulwark',
    'bum',
    'bumble',
    'bumblebee',
    'bumblebees',
    'bumbler',
    'bumbling',
    'bumboat',
    'bumelia',
    'bumf',
    'bummer',
    'bumming',
    'bump',
    'bumped',
    'bumper',
    'bumpers',
    'bumph',
    'bumpiness',
    'bumpkin',
    'bumpkinly',
    'bumps',
    'bumptious',
    'bumptiousness',
    'bumpy',
    'bun',
    'buna',
    'bunce',
    'bunch',
    'bunchberry',
    'bunche',
    'bunched',
    'bunches',
    'bunchgrass',
    'bunchy',
    'bunco',
    'buncombe',
    'bundesbank',
    'bundle',
    'bundled',
    'bundles',
    'bundling',
    'bunfight',
    'bung',
    'bungaloid',
    'bungalow',
    'bungarus',
    'bungee',
    'bunghole',
    'bungle',
    'bungled',
    'bungler',
    'bunglesome',
    'bungling',
    'bunion',
    'bunk',
    'bunked',
    'bunker',
    'bunkers',
    'bunkmate',
    'bunko',
    'bunks',
    'bunkum',
    'bunny',
    'buns',
    'bunsen',
    'bunt',
    'buntal',
    'bunted',
    'bunter',
    'bunting',
    'buntings',
    'bunts',
    'bunuel',
    'bunyan',
    'bunyaviridae',
    'bunyavirus',
    'buoy',
    'buoyancy',
    'buoyant',
    'buoyed',
    'buoys',
    'buphthalmum',
    'bur',
    'bura',
    'burbage',
    'burbank',
    'burberry',
    'burble',
    'burbling',
    'burbly',
    'burbot',
    'burden',
    'burdened',
    'burdenless',
    'burdens',
    'burdensome',
    'burdensomeness',
    'burdock',
    'bureau',
    'bureaucracies',
    'bureaucracy',
    'bureaucrat',
    'bureaucratic',
    'bureaucratism',
    'bureaucrats',
    'bureaus',
    'buret',
    'burette',
    'burg',
    'burgeon',
    'burgeoning',
    'burger',
    'burgess',
    'burgh',
    'burgher',
    'burglar',
    'burglaries',
    'burglarious',
    'burglarise',
    'burglarize',
    'burglarproof',
    'burglars',
    'burglary',
    'burgle',
    'burgomaster',
    'burgoo',
    'burgoyne',
    'burgrass',
    'burgrave',
    'burgundies',
    'burgundy',
    'burhinidae',
    'burhinus',
    'burial',
    'burials',
    'buried',
    'burin',
    'burk',
    'burka',
    'burke',
    'burkina',
    'burl',
    'burlap',
    'burled',
    'burlesque',
    'burlington',
    'burls',
    'burly',
    'burma',
    'burmannia',
    'burmanniaceae',
    'burmeisteria',
    'burmese',
    'burn',
    'burnability',
    'burnable',
    'burned',
    'burner',
    'burners',
    'burnett',
    'burnham',
    'burning',
    'burnish',
    'burnished',
    'burnoose',
    'burnous',
    'burnouse',
    'burns',
    'burnside',
    'burnt',
    'burnup',
    'burp',
    'burping',
    'burqa',
    'burr',
    'burrawong',
    'burred',
    'burrfish',
    'burrfishes',
    'burrito',
    'burrlike',
    'burro',
    'burroughs',
    'burrow',
    'burrowing',
    'burrows',
    'burrs',
    'burry',
    'burs',
    'bursa',
    'bursal',
    'bursar',
    'bursary',
    'bursera',
    'burseraceae',
    'bursiform',
    'bursitis',
    'burst',
    'burster',
    'bursting',
    'bursts',
    'burt',
    'burthen',
    'burton',
    'burundi',
    'burundian',
    'burunduki',
    'bury',
    'burying',
    'bus',
    'busbar',
    'busboy',
    'busby',
    'buses',
    'bush',
    'bushbaby',
    'bushbuck',
    'bushbucks',
    'bushed',
    'bushel',
    'bushels',
    'bushes',
    'bushido',
    'bushing',
    'bushman',
    'bushnell',
    'bushtit',
    'bushwhack',
    'bushwhacker',
    'bushwhacking',
    'bushy',
    'busies',
    'busiest',
    'busily',
    'business',
    'businesses',
    'businesslike',
    'businessman',
    'businessmen',
    'businesspeople',
    'businessperson',
    'businesswoman',
    'busk',
    'busker',
    'buskin',
    'busking',
    'busload',
    'busman',
    'buspar',
    'buspirone',
    'buss',
    'bussed',
    'bust',
    'bustard',
    'bustards',
    'busted',
    'buster',
    'bustier',
    'busting',
    'bustle',
    'bustled',
    'bustling',
    'busts',
    'busty',
    'busy',
    'busybodied',
    'busybody',
    'busyness',
    'busywork',
    'but',
    'butacaine',
    'butadiene',
    'butane',
    'butanes',
    'butanol',
    'butanone',
    'butat',
    'butazolidin',
    'butch',
    'butcher',
    'butcherbird',
    'butcherbirds',
    'butchered',
    'butchering',
    'butcherly',
    'butchery',
    'butea',
    'butene',
    'buteo',
    'buteonine',
    'butler',
    'butt',
    'butte',
    'butted',
    'butter',
    'butterball',
    'butterbean',
    'butterbur',
    'buttercrunch',
    'buttercup',
    'buttercups',
    'buttered',
    'butterfat',
    'butterfield',
    'butterfingered',
    'butterfingers',
    'butterfish',
    'butterfishes',
    'butterflies',
    'butterflower',
    'butterfly',
    'butterflyfish',
    'buttermilk',
    'butternut',
    'butterscotch',
    'butterweed',
    'butterwort',
    'buttery',
    'buttinsky',
    'buttock',
    'buttocks',
    'button',
    'buttoned',
    'buttonhole',
    'buttonholes',
    'buttonhook',
    'buttonlike',
    'buttons',
    'buttonwood',
    'buttony',
    'buttress',
    'buttressed',
    'buttresses',
    'buttressing',
    'butts',
    'buttweld',
    'butty',
    'butut',
    'bututs',
    'butyl',
    'butylate',
    'butylene',
    'butyraceous',
    'butyric',
    'butyrin',
    'buxaceae',
    'buxom',
    'buxomness',
    'buxus',
    'buy',
    'buyback',
    'buyer',
    'buyers',
    'buyi',
    'buying',
    'buyout',
    'buyouts',
    'buys',
    'buzz',
    'buzzard',
    'buzzards',
    'buzzed',
    'buzzer',
    'buzzing',
    'buzzword',
    'bvd',
    'bw',
    'bwr',
    'by',
    'byblos',
    'bycatch',
    'bydgoszcz',
    'bye',
    'byelarus',
    'byelorussia',
    'byelorussian',
    'bygone',
    'bygones',
    'bylaw',
    'byname',
    'bypass',
    'bypasses',
    'bypassing',
    'bypast',
    'bypath',
    'byplay',
    'byproduct',
    'byrd',
    'byre',
    'byrnie',
    'byroad',
    'byron',
    'bysshe',
    'byssus',
    'bystander',
    'byte',
    'bytes',
    'byway',
    'byword',
    'byzant',
    'byzantine',
    'byzantinism',
    'byzantium']




#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_v_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.237957'}

wordnet_terms_v = [
    'va',
    'vac',
    'vacancy',
    'vacant',
    'vacate',
    'vacated',
    'vacating',
    'vacation',
    'vacationer',
    'vacationers',
    'vacationing',
    'vacationist',
    'vacations',
    'vacay',
    'vaccaria',
    'vaccina',
    'vaccinate',
    'vaccinated',
    'vaccinating',
    'vaccination',
    'vaccinations',
    'vaccinator',
    'vaccine',
    'vaccinee',
    'vaccinia',
    'vaccinium',
    'vaccinum',
    'vacillant',
    'vacillate',
    'vacillating',
    'vacillation',
    'vacillator',
    'vacuity',
    'vacuolate',
    'vacuolated',
    'vacuolation',
    'vacuole',
    'vacuoles',
    'vacuolisation',
    'vacuolization',
    'vacuous',
    'vacuousness',
    'vacuum',
    'vacuumed',
    'vader',
    'vaduz',
    'vagabond',
    'vagabondage',
    'vagabonds',
    'vagal',
    'vagaries',
    'vagary',
    'vagile',
    'vagina',
    'vaginal',
    'vaginismus',
    'vaginitis',
    'vaginocele',
    'vagrancy',
    'vagrant',
    'vagrants',
    'vague',
    'vaguely',
    'vagueness',
    'vagus',
    'vain',
    'vainglorious',
    'vainglory',
    'vainly',
    'vaisakha',
    'vaishnava',
    'vaishnavism',
    'vaisnavism',
    'vaisya',
    'vajra',
    'valance',
    'valdecoxib',
    'valdez',
    'valdosta',
    'vale',
    'valediction',
    'valedictorian',
    'valedictory',
    'valence',
    'valences',
    'valencia',
    'valenciennes',
    'valency',
    'valent',
    'valentine',
    'valerian',
    'valeriana',
    'valerianaceae',
    'valerianella',
    'valet',
    'valetta',
    'valetudinarian',
    'valetudinarianism',
    'valetudinary',
    'valgus',
    'valhalla',
    'vali',
    'valiance',
    'valiancy',
    'valiant',
    'valid',
    'validate',
    'validated',
    'validates',
    'validating',
    'validation',
    'validatory',
    'validity',
    'validness',
    'valine',
    'valise',
    'valium',
    'valkyrie',
    'vallecula',
    'valletta',
    'valley',
    'valleys',
    'vallisneria',
    'valmy',
    'valois',
    'valor',
    'valorem',
    'valorous',
    'valorousness',
    'valour',
    'valparaiso',
    'valsartan',
    'valse',
    'valuable',
    'valuableness',
    'valuables',
    'valuate',
    'valuation',
    'valuator',
    'value',
    'valued',
    'valueless',
    'valuelessness',
    'valuer',
    'values',
    'valve',
    'valved',
    'valvelet',
    'valves',
    'valvotomy',
    'valvula',
    'valvular',
    'valvule',
    'valvulitis',
    'valvulotomy',
    'vambrace',
    'vamoose',
    'vamp',
    'vamper',
    'vampire',
    'vampires',
    'vampirism',
    'van',
    'vanadate',
    'vanadic',
    'vanadinite',
    'vanadium',
    'vanbrugh',
    'vancocin',
    'vancomycin',
    'vancouver',
    'vanda',
    'vandal',
    'vandalise',
    'vandalism',
    'vandalize',
    'vandals',
    'vanderbilt',
    'vandyke',
    'vane',
    'vaned',
    'vanellus',
    'vanern',
    'vanes',
    'vanessa',
    'vanguard',
    'vangueria',
    'vanilla',
    'vanillin',
    'vanir',
    'vanish',
    'vanished',
    'vanisher',
    'vanishing',
    'vanities',
    'vanity',
    'vannever',
    'vanquish',
    'vanquishable',
    'vanquished',
    'vanquisher',
    'vans',
    'vantage',
    'vanua',
    'vanuatu',
    'vanzetti',
    'vapid',
    'vapidity',
    'vapidness',
    'vapor',
    'vaporific',
    'vaporing',
    'vaporisation',
    'vaporise',
    'vaporiser',
    'vaporish',
    'vaporizable',
    'vaporization',
    'vaporize',
    'vaporized',
    'vaporizer',
    'vaporizes',
    'vaporizing',
    'vaporous',
    'vaporousness',
    'vapors',
    'vapour',
    'vapourific',
    'vapourisable',
    'vapourised',
    'vapourish',
    'vapourous',
    'vapourousness',
    'vapours',
    'vaquero',
    'vaquita',
    'var',
    'vara',
    'varan',
    'varanidae',
    'varanus',
    'vardenafil',
    'varese',
    'vargas',
    'variability',
    'variable',
    'variableness',
    'variables',
    'variably',
    'variance',
    'variant',
    'variate',
    'variates',
    'variation',
    'variations',
    'varicella',
    'varicelliform',
    'varicocele',
    'varicolored',
    'varicoloured',
    'varicose',
    'varicosis',
    'varicosity',
    'varied',
    'variedness',
    'variegate',
    'variegated',
    'variegation',
    'varies',
    'varietal',
    'varieties',
    'variety',
    'variform',
    'variola',
    'variolar',
    'variolation',
    'variolic',
    'variolization',
    'variolous',
    'variometer',
    'variorum',
    'various',
    'variously',
    'varix',
    'varlet',
    'varment',
    'varmint',
    'varna',
    'varnish',
    'varnished',
    'varnisher',
    'varnishes',
    'varro',
    'varsity',
    'varuna',
    'varus',
    'vary',
    'varying',
    'vas',
    'vasa',
    'vasarely',
    'vasari',
    'vascular',
    'vascularisation',
    'vascularise',
    'vascularity',
    'vascularization',
    'vascularize',
    'vasculitis',
    'vase',
    'vasectomise',
    'vasectomize',
    'vasectomized',
    'vasectomy',
    'vaseline',
    'vasiform',
    'vasoconstriction',
    'vasoconstrictive',
    'vasoconstrictor',
    'vasodilation',
    'vasodilative',
    'vasodilator',
    'vasomax',
    'vasomotor',
    'vasopressin',
    'vasopressor',
    'vasosection',
    'vasotec',
    'vasotomy',
    'vasovasostomy',
    'vasovesiculitis',
    'vassal',
    'vassalage',
    'vassals',
    'vast',
    'vastness',
    'vat',
    'vatic',
    'vatical',
    'vatican',
    'vaticinate',
    'vaticination',
    'vaticinator',
    'vaudeville',
    'vaudevillian',
    'vaudois',
    'vaughan',
    'vault',
    'vaulted',
    'vaulter',
    'vaulting',
    'vaults',
    'vaunt',
    'vaunter',
    'vaux',
    'vayu',
    'vcr',
    'vd',
    'vdu',
    'veadar',
    'veal',
    'veau',
    'veblen',
    'vector',
    'vectors',
    'veda',
    'vedalia',
    'vedanga',
    'vedanta',
    'vedas',
    'vedic',
    'vedism',
    'vedist',
    'veer',
    'veered',
    'veering',
    'veery',
    'veg',
    'vega',
    'vegan',
    'vegetable',
    'vegetables',
    'vegetal',
    'vegetarian',
    'vegetarianism',
    'vegetate',
    'vegetated',
    'vegetates',
    'vegetation',
    'vegetational',
    'vegetative',
    'vegetive',
    'veggie',
    'vehemence',
    'vehement',
    'vehemently',
    'vehicle',
    'vehicles',
    'vehicular',
    'veil',
    'veiled',
    'veiling',
    'veils',
    'vein',
    'veinal',
    'veined',
    'veining',
    'veinlike',
    'veins',
    'vela',
    'velar',
    'velazquez',
    'velban',
    'velcro',
    'veld',
    'veldt',
    'velleity',
    'vellicate',
    'vellication',
    'vellum',
    'velocipede',
    'velociraptor',
    'velocities',
    'velocity',
    'velodrome',
    'velour',
    'velours',
    'veloute',
    'velox',
    'velum',
    'velveeta',
    'velvet',
    'velveteen',
    'velvetleaf',
    'velvetweed',
    'velvety',
    'vena',
    'venae',
    'venal',
    'venality',
    'venation',
    'vend',
    'vendable',
    'vendee',
    'vendemiaire',
    'vender',
    'vendetta',
    'vendible',
    'vending',
    'vendition',
    'vendor',
    'vendue',
    'veneer',
    'veneering',
    'veneers',
    'venerability',
    'venerable',
    'venerableness',
    'venerate',
    'venerated',
    'venerates',
    'venerating',
    'veneration',
    'venerator',
    'venereal',
    'venereum',
    'veneridae',
    'venesect',
    'venesection',
    'venetia',
    'venetian',
    'venetians',
    'veneto',
    'venezia',
    'venezuela',
    'venezuelan',
    'vengeance',
    'vengeful',
    'vengefulness',
    'venial',
    'venice',
    'venipuncture',
    'venire',
    'venison',
    'venn',
    'venogram',
    'venography',
    'venom',
    'venomed',
    'venomous',
    'venose',
    'venous',
    'vent',
    'ventail',
    'vented',
    'venter',
    'venthole',
    'ventilate',
    'ventilated',
    'ventilating',
    'ventilation',
    'ventilator',
    'ventilatory',
    'venting',
    'ventner',
    'ventolin',
    'ventose',
    'ventral',
    'ventrally',
    'ventricle',
    'ventricles',
    'ventricose',
    'ventricous',
    'ventricular',
    'ventriculus',
    'ventriloquism',
    'ventriloquist',
    'ventriloquy',
    'vents',
    'venture',
    'ventured',
    'venturer',
    'ventures',
    'venturesome',
    'venturesomeness',
    'venturi',
    'venturing',
    'venturous',
    'venue',
    'venues',
    'venula',
    'venule',
    'venules',
    'venus',
    'venushair',
    'veps',
    'vepse',
    'vepsian',
    'veracious',
    'veracity',
    'veracruz',
    'veranda',
    'verandah',
    'verapamil',
    'veratrum',
    'verb',
    'verbal',
    'verbalisation',
    'verbalise',
    'verbalised',
    'verbaliser',
    'verbalism',
    'verbalization',
    'verbalize',
    'verbalized',
    'verbalizer',
    'verbalizes',
    'verbally',
    'verbascum',
    'verbatim',
    'verbena',
    'verbenaceae',
    'verbesina',
    'verbetrate',
    'verbiage',
    'verbified',
    'verbify',
    'verbolatry',
    'verbose',
    'verbosely',
    'verboseness',
    'verbosity',
    'verboten',
    'verbs',
    'verdancy',
    'verdandi',
    'verdant',
    'verde',
    'verdi',
    'verdicchio',
    'verdict',
    'verdigris',
    'verdin',
    'verdolagas',
    'verdun',
    'verdure',
    'verge',
    'verged',
    'verger',
    'verges',
    'vergil',
    'verging',
    'veridical',
    'verifiable',
    'verification',
    'verificatory',
    'verified',
    'verifier',
    'verifies',
    'verify',
    'verifying',
    'verisimilar',
    'verisimilitude',
    'veritable',
    'verity',
    'verlaine',
    'vermeer',
    'vermicelli',
    'vermicide',
    'vermicular',
    'vermiculate',
    'vermiculated',
    'vermiculation',
    'vermiculite',
    'vermiform',
    'vermifuge',
    'vermilion',
    'vermillion',
    'vermin',
    'verminous',
    'vermis',
    'vermont',
    'vermonter',
    'vermouth',
    'vernacular',
    'vernal',
    'vernata',
    'vernation',
    'verne',
    'verner',
    'vernier',
    'vernix',
    'vernonia',
    'verona',
    'veronal',
    'veronese',
    'veronica',
    'verpa',
    'verrazano',
    'verrazzano',
    'verruca',
    'verrucose',
    'versa',
    'versace',
    'versailles',
    'versant',
    'versatile',
    'versatility',
    'verse',
    'versed',
    'verses',
    'versicle',
    'versification',
    'versified',
    'versifier',
    'versify',
    'version',
    'versions',
    'verso',
    'verst',
    'versus',
    'vertebra',
    'vertebrae',
    'vertebral',
    'vertebrata',
    'vertebrate',
    'vertebrates',
    'vertex',
    'verthandi',
    'vertical',
    'verticality',
    'vertically',
    'verticalness',
    'vertices',
    'verticil',
    'verticillate',
    'verticillated',
    'verticilliosis',
    'verticillium',
    'vertiginous',
    'vertigo',
    'vertu',
    'vervain',
    'verve',
    'vervet',
    'verwoerd',
    'very',
    'vesalius',
    'vesey',
    'vesica',
    'vesical',
    'vesicant',
    'vesicaria',
    'vesicate',
    'vesication',
    'vesicatory',
    'vesicle',
    'vesicles',
    'vesicopapule',
    'vesicular',
    'vesiculate',
    'vesiculation',
    'vesiculitis',
    'vesiculovirus',
    'vespa',
    'vespasian',
    'vesper',
    'vespers',
    'vespertilio',
    'vespertilionid',
    'vespertilionidae',
    'vespid',
    'vespidae',
    'vespucci',
    'vespula',
    'vessel',
    'vessels',
    'vest',
    'vesta',
    'vestal',
    'vested',
    'vestiary',
    'vestibular',
    'vestibule',
    'vestige',
    'vestiges',
    'vestigial',
    'vestiture',
    'vestment',
    'vestmental',
    'vestmented',
    'vestments',
    'vestris',
    'vestry',
    'vestryman',
    'vestrywoman',
    'vests',
    'vesture',
    'vesuvian',
    'vesuvianite',
    'vesuvius',
    'vet',
    'vetch',
    'vetches',
    'vetchling',
    'vetchworm',
    'veteran',
    'veterans',
    'veterinarian',
    'veterinarians',
    'veterinary',
    'vetluga',
    'veto',
    'vetoed',
    'vetted',
    'vex',
    'vexation',
    'vexations',
    'vexatious',
    'vexatiously',
    'vexed',
    'vexer',
    'vexing',
    'vfw',
    'vhf',
    'vi',
    'via',
    'viability',
    'viable',
    'viaduct',
    'viagra',
    'vial',
    'viand',
    'viands',
    'viatical',
    'viatication',
    'viaticus',
    'vibe',
    'vibes',
    'vibist',
    'viborg',
    'vibraharp',
    'vibramycin',
    'vibrancy',
    'vibrant',
    'vibraphone',
    'vibraphonist',
    'vibrate',
    'vibrates',
    'vibrating',
    'vibration',
    'vibrational',
    'vibrations',
    'vibrato',
    'vibrator',
    'vibratory',
    'vibrio',
    'vibrion',
    'vibrionic',
    'vibrissa',
    'viburnum',
    'vic',
    'vicar',
    'vicarage',
    'vicarial',
    'vicariate',
    'vicarious',
    'vicarship',
    'vice',
    'vicegerent',
    'vicenary',
    'vicennial',
    'viceregal',
    'vicereine',
    'viceroy',
    'viceroyalty',
    'viceroys',
    'viceroyship',
    'vices',
    'vichy',
    'vichyssoise',
    'vicia',
    'vicinal',
    'vicinity',
    'vicious',
    'viciously',
    'viciousness',
    'vicissitude',
    'vicissitudes',
    'vicksburg',
    'victim',
    'victimisation',
    'victimise',
    'victimised',
    'victimiser',
    'victimization',
    'victimize',
    'victimized',
    'victimizer',
    'victimizes',
    'victimizing',
    'victimless',
    'victims',
    'victor',
    'victoria',
    'victorian',
    'victoriana',
    'victories',
    'victorious',
    'victors',
    'victory',
    'victrola',
    'victual',
    'victualed',
    'victualer',
    'victualled',
    'victualler',
    'victuals',
    'vicugna',
    'vicuna',
    'vicunas',
    'vidal',
    'vidalia',
    'vidar',
    'video',
    'videocassette',
    'videocassettes',
    'videodisc',
    'videodisk',
    'videotape',
    'videotapes',
    'vidua',
    'vie',
    'vienna',
    'vienne',
    'viennese',
    'vientiane',
    'vieques',
    'viet',
    'vietnam',
    'vietnamese',
    'view',
    'viewable',
    'viewed',
    'viewer',
    'viewers',
    'viewfinder',
    'viewgraph',
    'viewing',
    'viewless',
    'viewpoint',
    'viewpoints',
    'views',
    'vigesimal',
    'vigil',
    'vigilance',
    'vigilant',
    'vigilante',
    'vigilantism',
    'vigna',
    'vignette',
    'vigor',
    'vigorish',
    'vigorous',
    'vigorously',
    'vigour',
    'vii',
    'viii',
    'viking',
    'vikings',
    'vila',
    'vile',
    'vileness',
    'vilhjalmur',
    'vilification',
    'vilified',
    'vilifier',
    'vilify',
    'vilipend',
    'villa',
    'village',
    'villager',
    'villages',
    'villahermosa',
    'villain',
    'villainage',
    'villainess',
    'villainous',
    'villainousness',
    'villainy',
    'villard',
    'villein',
    'villeinage',
    'villi',
    'villoma',
    'villon',
    'villus',
    'vilna',
    'vilnius',
    'vilno',
    'vim',
    'viminaria',
    'vinaceous',
    'vinaigrette',
    'vinblastine',
    'vinca',
    'vincent',
    'vincetoxicum',
    'vinci',
    'vincible',
    'vincristine',
    'vindicate',
    'vindicated',
    'vindicating',
    'vindication',
    'vindicator',
    'vindicatory',
    'vindictive',
    'vindictiveness',
    'vine',
    'vinegar',
    'vinegariness',
    'vinegarish',
    'vinegarishness',
    'vinegarroon',
    'vinegarweed',
    'vinegary',
    'vinery',
    'vines',
    'vineyard',
    'vineyards',
    'viniculture',
    'vinifera',
    'vinification',
    'vinify',
    'vino',
    'vinogradoff',
    'vinous',
    'vinson',
    'vintage',
    'vintager',
    'vintner',
    'vinyl',
    'vinylbenzene',
    'vinylite',
    'viocin',
    'viol',
    'viola',
    'violable',
    'violaceae',
    'violas',
    'violate',
    'violated',
    'violates',
    'violating',
    'violation',
    'violations',
    'violative',
    'violator',
    'violators',
    'violence',
    'violent',
    'violently',
    'violet',
    'violets',
    'violin',
    'violinist',
    'violinists',
    'violins',
    'violist',
    'violoncellist',
    'violoncello',
    'viomycin',
    'viosterol',
    'vioxx',
    'vip',
    'viper',
    'vipera',
    'viperidae',
    'vipers',
    'viracept',
    'viraemia',
    'virago',
    'viral',
    'viramune',
    'virazole',
    'virchow',
    'viremia',
    'vireo',
    'vireonidae',
    'vires',
    'virga',
    'virgil',
    'virgilia',
    'virgin',
    'virginal',
    'virginia',
    'virginian',
    'virginica',
    'virginity',
    'virgins',
    'virgo',
    'virgule',
    'viricidal',
    'viricide',
    'viridity',
    'virile',
    'virilisation',
    'virilise',
    'virilism',
    'virility',
    'virilization',
    'virilize',
    'virino',
    'virion',
    'viroid',
    'virological',
    'virologist',
    'virology',
    'virtu',
    'virtual',
    'virtually',
    'virtue',
    'virtues',
    'virtuosic',
    'virtuosity',
    'virtuoso',
    'virtuous',
    'virtuousness',
    'virucidal',
    'virucide',
    'virulence',
    'virulency',
    'virulent',
    'virus',
    'viruses',
    'virusoid',
    'visa',
    'visage',
    'visaged',
    'visayan',
    'viscaceae',
    'viscacha',
    'viscachas',
    'viscera',
    'visceral',
    'viscid',
    'viscidity',
    'viscidness',
    'viscoelastic',
    'viscometer',
    'viscometric',
    'viscometry',
    'visconti',
    'viscose',
    'viscosimeter',
    'viscosimetric',
    'viscosimetry',
    'viscosity',
    'viscount',
    'viscountcy',
    'viscountess',
    'viscounty',
    'viscous',
    'viscousness',
    'viscum',
    'viscus',
    'vise',
    'viselike',
    'vishnu',
    'vishnuism',
    'visibility',
    'visible',
    'visibleness',
    'visibly',
    'visigoth',
    'visigoths',
    'vision',
    'visionary',
    'visions',
    'visit',
    'visitant',
    'visitation',
    'visitations',
    'visited',
    'visiting',
    'visitor',
    'visitors',
    'visits',
    'visken',
    'visor',
    'visored',
    'visors',
    'vista',
    'vistaril',
    'vistas',
    'vistula',
    'visual',
    'visualisation',
    'visualise',
    'visualised',
    'visualiser',
    'visualization',
    'visualize',
    'visualized',
    'visualizer',
    'visually',
    'vitaceae',
    'vitae',
    'vital',
    'vitalisation',
    'vitalise',
    'vitaliser',
    'vitalism',
    'vitalist',
    'vitality',
    'vitalization',
    'vitalize',
    'vitalized',
    'vitalizer',
    'vitalizing',
    'vitally',
    'vitalness',
    'vitals',
    'vitamin',
    'vitaminise',
    'vitaminize',
    'vitamins',
    'vitellus',
    'vithar',
    'vitharr',
    'viti',
    'vitiate',
    'vitiated',
    'vitiation',
    'viticulture',
    'viticulturist',
    'vitidaceae',
    'vitiliginous',
    'vitiligo',
    'vitis',
    'vitrectomy',
    'vitreous',
    'vitrification',
    'vitrified',
    'vitrify',
    'vitrine',
    'vitriol',
    'vitriolic',
    'vitro',
    'vittaria',
    'vittariaceae',
    'vituperate',
    'vituperation',
    'vituperative',
    'vitus',
    'viva',
    'vivace',
    'vivacious',
    'vivacity',
    'vivaldi',
    'vivarium',
    'viverra',
    'viverricula',
    'viverridae',
    'viverrinae',
    'viverrine',
    'vivid',
    'vividly',
    'vividness',
    'vivification',
    'vivify',
    'viviparous',
    'vivisect',
    'vivisection',
    'vivisectionist',
    'vivo',
    'vixen',
    'vixenish',
    'viyella',
    'vizcaino',
    'vizier',
    'viziership',
    'vizor',
    'vizsla',
    'vj',
    'vladimir',
    'vladivostok',
    'vlaminck',
    'vldl',
    'vldls',
    'vlf',
    'vocable',
    'vocabulary',
    'vocal',
    'vocalic',
    'vocalisation',
    'vocalise',
    'vocaliser',
    'vocalism',
    'vocalist',
    'vocalization',
    'vocalizations',
    'vocalize',
    'vocalized',
    'vocalizer',
    'vocalizing',
    'vocally',
    'vocals',
    'vocation',
    'vocational',
    'vocative',
    'vociferate',
    'vociferated',
    'vociferation',
    'vociferator',
    'vociferous',
    'vodka',
    'vodoun',
    'vogue',
    'voguish',
    'vogul',
    'voice',
    'voiced',
    'voiceless',
    'voicelessness',
    'voicemail',
    'voiceprint',
    'voicer',
    'voices',
    'voicing',
    'void',
    'voidable',
    'voidance',
    'voided',
    'voider',
    'voiding',
    'voile',
    'volaille',
    'volans',
    'volapuk',
    'volar',
    'volary',
    'volatile',
    'volatilisable',
    'volatilise',
    'volatilised',
    'volatility',
    'volatilizable',
    'volatilize',
    'volatilized',
    'volatilizing',
    'volcanic',
    'volcanism',
    'volcano',
    'volcanoes',
    'volcanology',
    'vole',
    'voles',
    'volga',
    'volgaic',
    'volgograd',
    'volition',
    'volitional',
    'volitionally',
    'volkhov',
    'volley',
    'volleyball',
    'volleyed',
    'volleys',
    'volt',
    'volta',
    'voltage',
    'voltages',
    'voltaic',
    'voltaire',
    'voltarean',
    'voltaren',
    'voltarian',
    'voltmeter',
    'volts',
    'volubility',
    'voluble',
    'volubly',
    'volume',
    'volumed',
    'volumes',
    'volumeter',
    'volumetric',
    'volumetrical',
    'voluminosity',
    'voluminous',
    'voluminously',
    'voluminousness',
    'volund',
    'voluntarily',
    'voluntary',
    'volunteer',
    'volunteered',
    'volunteering',
    'volunteers',
    'voluptuary',
    'voluptuous',
    'voluptuously',
    'voluptuousness',
    'volute',
    'voluted',
    'volution',
    'volva',
    'volvaria',
    'volvariaceae',
    'volvariella',
    'volvelle',
    'volvocaceae',
    'volvocales',
    'volvox',
    'volvulus',
    'vombatidae',
    'vomer',
    'vomica',
    'vomit',
    'vomited',
    'vomiter',
    'vomiting',
    'vomitive',
    'vomitory',
    'vomits',
    'vomitus',
    'von',
    'vonnegut',
    'voodoo',
    'voodooism',
    'voracious',
    'voraciously',
    'voraciousness',
    'voracity',
    'vorse',
    'vortex',
    'vorticella',
    'votary',
    'vote',
    'voted',
    'voteless',
    'voter',
    'voters',
    'votes',
    'voting',
    'votive',
    'votyak',
    'vouch',
    'vouched',
    'vouchee',
    'voucher',
    'vouches',
    'vouchsafe',
    'vouge',
    'voussoir',
    'voussoirs',
    'vouvray',
    'vow',
    'vowed',
    'vowel',
    'vowelise',
    'vowelize',
    'vowellike',
    'vowels',
    'vower',
    'vowers',
    'vows',
    'vox',
    'voyage',
    'voyager',
    'voyages',
    'voyeur',
    'voyeurism',
    'voyeuristic',
    'voyeuristical',
    'voyeurs',
    'voznesenski',
    'vroom',
    'vt',
    'vuillard',
    'vulcan',
    'vulcanisation',
    'vulcanise',
    'vulcanised',
    'vulcaniser',
    'vulcanite',
    'vulcanization',
    'vulcanize',
    'vulcanized',
    'vulcanizer',
    'vulcanizes',
    'vulcanizing',
    'vulcanology',
    'vulgar',
    'vulgarian',
    'vulgaris',
    'vulgarisation',
    'vulgarise',
    'vulgariser',
    'vulgarism',
    'vulgarity',
    'vulgarization',
    'vulgarize',
    'vulgarized',
    'vulgarizer',
    'vulgate',
    'vulnerability',
    'vulnerable',
    'vulnerably',
    'vulpecula',
    'vulpecular',
    'vulpes',
    'vulpine',
    'vultur',
    'vulture',
    'vultures',
    'vulturine',
    'vulturous',
    'vulva',
    'vulval',
    'vulvar',
    'vulvectomy',
    'vulvitis',
    'vulvovaginitis',
    'vx']



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Perform spaCy parse and retokenization """


import spacy
from spacy.tokens import Doc
from spacy.lang.en import English
from lingpatlab.baseblock import BaseObject


class TokenParserSpacy(BaseObject):
    """ Perform spaCy parse and retokenization """

    def __init__(self,
                 en_spacy_model: English | None = None):
        """ Change Log

        Created:
            13-Oct-2021
            craigtrim@gmail.com
            *   refactored out of 'parse-input-tokens' in pursuit of
                https://github.com/grafflr/graffl-core/issues/41
        Updated:
            16-Sept-2022
            craigtrim@gmail.com
            *   rename component
                https://github.com/craigtrim/spacy-token-parser/issues/3
        Updated:
            16-Aug-2024
            craigtrim@gmail.com
            *   optimize model instantiation
                https://github.com/craigtrim/LingPatLab/issues/2
        """
        BaseObject.__init__(self, __name__)
        if en_spacy_model is not None:
            self._nlp = en_spacy_model
        else:
            self._nlp = spacy.load('en_core_web_sm')

    def process(self,
                input_text: str) -> Doc:
        """Perform actual spaCy parse and retokenize input

        Args:
            tokens (list): list of tokens

        Returns:
            Doc: spacy doc
        """
        doc = self._nlp(input_text)

        # ----------------------------------------------------------------------------------
        # Purpose:    Perform Retokenization
        # Reference:  https://github.com/grafflr/graffl-core/issues/1#issuecomment-935048135
        # Updated:    22-Nov-2021
        # ----------------------------------------------------------------------------------
        position = [
            token.i for token in doc
            if token.i != 0 and "'" in token.text
        ]

        with doc.retokenize() as retokenizer:
            for pos in position:

                spans = doc[pos - 1:pos + 1]

                # --------------------------------------------------------------
                # Purpose:      I don't really understand the error ...
                # Reference:    https://spacy.io/api/top-level#util.filter_spans
                # Updated:      27-Feb-2024
                # --------------------------------------------------------------
                try:
                    retokenizer.merge(spans)
                except ValueError as e:
                    self.logger.error(e)

        return doc



# -*- coding: utf-8 -*-
""" Crytography Base Functions """


import os

from typing import Optional

from cryptography.fernet import Fernet
from cryptography.fernet import InvalidToken

enc = 'utf-8'


class CryptoBase(object):
    """ Crytography Base Functions """

    def __init__(self,
                 crypto_key: Optional[str] = None):
        """ Change Log

        Created:
            2-Mar-2022
            craigtrim@gmail.com
            *   https://github.com/craigtrim/baseblock/issues/1
        Updated:
            20-Oct-2022
            craigtrim@gmail.com
            *   remove hard-coded crypto key
                https://github.com/craigtrim/baseblock/issues/4

        Args:
            crypto_key (str): the fernet private key
        """
        def get_key() -> str:
            if crypto_key:
                return crypto_key
            if 'BASEBLOCK_CRYPTO_KEY' in os.environ:
                return os.environ['BASEBLOCK_CRYPTO_KEY']
            raise ValueError('Crypto Key Not Found')

        self._key = get_key()

    @staticmethod
    def generate_private_key() -> str:
        """ Use to Generate Private Key for ecrypting and decrypting text
        This key will be passed in as a value to the constructor of CryptoBase

        Returns:
            str: the private key
        """
        return Fernet.generate_key()

    def encrypt_str(self,
                    some_input: str) -> str:
        """ Encrypt a String

        Args:
            some_input (str): any input string

        Returns:
            str: the encrypted string
        """
        result = str(self.encrypt(some_input.encode(enc)))

        # eliminate the 'bytes' prefix and suffix markers
        if result.startswith("b'") and result.endswith("'"):
            return result[2:-1]

        return result

    def encrypt(self,
                message: bytes) -> str:
        """ Encrypt Bytes

        Args:
            message (bytes): any input bytes

        Returns:
            str: the encrypted string
        """
        f = Fernet(self._key)
        return str(f.encrypt(message))

    def decrypt_str(self,
                    some_input: str) -> str or None:
        """ Decrypt a String

        Args:
            some_input (str): any input string

        Raises:
            ValueError: the encrypted token is invalid

        Returns:
            str or None: the decrypted string if the encrypted token is valid
        """
        return self.decrypt(some_input.encode(enc))

    def decrypt(self,
                message: bytes) -> str:
        """ Decrypt Bytes

        Args:
            message (bytes): any input bytes

        Raises:
            ValueError: the encrypted token is invalid

        Returns:
            str: the decrypted string
        """
        try:
            f = Fernet(self._key)
            return f.decrypt(message).decode(enc)
        except InvalidToken:
            raise ValueError('Invalid Token')


def main(param1, param2):
    def _action():
        if param1 == 'encrypt':
            return CryptoBase().encrypt_str(param2)
        elif param1 == 'decrypt':
            return CryptoBase().decrypt_str(param2)
        else:
            raise NotImplementedError('\n'.join([
                'Unknown Param: {}'.format(param1)]))

    print(_action())


if __name__ == '__main__':
    import plac

    plac.call(main)



# -*- coding: utf-8 -*-
""" Environment Variable Utility Methods """


import os

from typing import List


class EnvIO(object):
    """ Environment Variable Utility Methods """

    @staticmethod
    def exists(env_var: str) -> bool:
        """Check if Environment Variable exists

        Args:
            env_var (str): the Environment Variable name

        Returns:
            bool: True if the Environment Variable exists
        """
        return env_var in os.environ and len(os.environ[env_var])

    @staticmethod
    def float_or_exception(*args) -> float:
        """Retrieve Environment Variable by Name or throw exception

        Args:
            args (list): a list of Environment Variable names

        Raises:
            ValueError: none of the Environment Variables were not found

        Returns:
            str: the first Environment Variable value to be found
        """
        for env_var in args:
            if EnvIO.exists(env_var):
                return EnvIO.as_float(env_var)
        raise ValueError(env_var)

    @staticmethod
    def float_or_default(env_var: str,
                         default: int) -> float:
        """Retrieve Environment Variable by Name or return default

        Args:
            env_var (str): the Environment Variable name
            default (float): the default value

        Returns:
            float: the Environment Variable value
        """
        if EnvIO.exists(env_var):
            return EnvIO.as_float(env_var)
        return default

    @staticmethod
    def int_or_exception(*args) -> int:
        """Retrieve Environment Variable by Name or throw exception

        Args:
            args (list): a list of Environment Variable names

        Raises:
            ValueError: none of the Environment Variables were not found

        Returns:
            str: the first Environment Variable value to be found
        """
        for env_var in args:
            if EnvIO.exists(env_var):
                return EnvIO.as_int(env_var)
        raise ValueError(env_var)

    @staticmethod
    def int_or_default(env_var: str,
                       default: int) -> int:
        """Retrieve Environment Variable by Name or return a default value

        Args:
            env_var (str): the Environment Variable name
            default (intg): the default value

        Returns:
            int: the Environment Variable value
        """
        if EnvIO.exists(env_var):
            return EnvIO.as_int(env_var)

        return default

    @staticmethod
    def str_or_default(env_var: str,
                       default: str) -> str:
        """Retrieve Environment Variable by Name or return a default value

        Args:
            env_var (str): the Environment Variable name
            default (str): the default value

        Returns:
            str: the Environment Variable value
        """
        return os.environ.get(env_var, default)

    @staticmethod
    def str_or_exception(*args) -> str:
        """Retrieve Environment Variable by Name or throw exception

        Args:
            args (list): a list of Environment Variable names

        Raises:
            ValueError: none of the Environment Variables were not found

        Returns:
            str: the first Environment Variable value to be found
        """
        for env_var in args:
            if EnvIO.exists(env_var):
                return EnvIO.as_str(env_var)

        raise ValueError(args)

    @staticmethod
    def as_list(*args,
                lower: bool = True) -> list:
        """Retrieve Environment Variable as a tokenized value to list

        Args:
            args (str): a list of one-or-more Environment Variable names

        Returns:
            str or None: a list representation of the values
        """
        for env_var in args:
            if env_var in os.environ:
                values = [x.strip() for x in os.environ[env_var].split(',')]
                values = [x for x in values if x and len(x)]
                if lower:
                    values = [x.lower() for x in values]
                return values

        return []

    @staticmethod
    def as_str(*args) -> str or None:
        """Retrieve Environment Variable as a string value

        Args:
            args (str): a list of one-or-more Environment Variable names

        Returns:
            str or None: a String representation of the value
        """
        for env_var in args:
            if env_var in os.environ:
                return str(os.environ[env_var])

    @staticmethod
    def as_int(*args) -> int or None:
        """Retrieve Environment Variable as an int value

        Args:
            args (str): a list of one-or-more Environment Variable names

        Returns:
            str or None: an int representation of the value
        """
        for env_var in args:
            if env_var in os.environ:
                try:
                    return int(os.environ[env_var])
                except ValueError:
                    pass

    @staticmethod
    def as_float(*args) -> float or None:
        """Retrieve Environment Variable as a float value

        Args:
            args (str): a list of one-or-more Environment Variable names

        Returns:
            str or None: a float representation of the value
        """
        for env_var in args:
            if env_var in os.environ:
                try:
                    return float(os.environ[env_var])
                except ValueError:
                    pass

    @staticmethod
    def is_true(env_var: str) -> bool:
        return os.getenv(env_var, 'False').lower() in ('true', '1', 't')

    @staticmethod
    def is_false(env_var: str) -> bool:
        return not EnvIO.is_true(env_var)

    @staticmethod
    def set_true(env_var: str) -> None:
        os.environ[env_var] = str(True)

    @staticmethod
    def set_false(env_var: str) -> None:
        os.environ[env_var] = str(False)

    @staticmethod
    def exists_as_true(env_var: str) -> bool:
        if EnvIO.exists(env_var):
            return EnvIO.is_true(env_var)
        return False

    @staticmethod
    def set_string(key: str,
                   value: str) -> None:
        os.environ[key] = value

    @staticmethod
    def set_int(key: str,
                value: int) -> None:
        os.environ[key] = str(value)

    @staticmethod
    def set_float(key: str,
                  value: float) -> None:
        os.environ[key] = str(value)



# -*- coding: utf-8 -*-


from pprint import pprint

from typing import List
from typing import Callable

from collections import defaultdict


class DataTypeNotExpectedError(Exception):
    """Exception raised for data type errors

    Attributes:
        actual_value -- the actual value
        expected_type -- the expected value
    """

    def __init__(self,
                 actual_value: str,
                 expected_type: object):
        message = '\n'.join([
            'Data Type Not Expected',
            f'\tActual Value: {expected_type}',
            f'\tActual Type: {type(actual_value)}',
            f'\tExpected Type: {expected_type}'])
        super().__init__(message)


class ContentNotExpectedError(Exception):
    """Exception raised for data content errors

    Attributes:
        actual_content -- the actual content
        expected_content -- the expected content
    """

    def __init__(self,
                 actual_content: str,
                 expected_content: object):
        message = '\n'.join([
            'Data Content Not Expected',
            f'\tExpected Content: {actual_content}',
            f'\tActual Content: {type(expected_content)}'])
        super().__init__(message)


class Enforcer(object):

    def __init__(self):
        pass

    @classmethod
    def is_tuple(cls,
                 value: object) -> None:
        if type(value) != tuple:
            raise DataTypeNotExpectedError(actual_value=value,
                                           expected_type='tuple')

    @classmethod
    def is_optional_tuple(cls,
                          value: object) -> None:
        if value is not None:
            cls.is_tuple(value)

    @classmethod
    def is_bool(cls,
                value: object,
                display: bool = False) -> None:
        if type(value) != bool:
            raise DataTypeNotExpectedError(actual_value=value,
                                           expected_type='bool')

        if display:
            print(value)

    @classmethod
    def is_str(cls,
               value: object,
               display: bool = False) -> None:
        if type(value) != str:
            raise DataTypeNotExpectedError(actual_value=value,
                                           expected_type='str')

        if display:
            print(value)

    @classmethod
    def is_optional_str(cls,
                        value: object,
                        display: bool = False) -> None:
        if value is not None:
            cls.is_str(value, display=display)

    @classmethod
    def is_int_or_float(cls,
                        value: object,
                        display: bool = False) -> None:
        """ Check if the incoming value is an Int or Float

        Args:
            value (object): the incoming value
            display (bool, optional): if True, display the value. Defaults to False.

        Raises:
            DataTypeNotExpectedError: the incoming value was neither an int nor a float
        """
        _type = type(value)
        if _type == int or _type == float:
            if display:
                print(value)
            return None

        raise DataTypeNotExpectedError(actual_value=value,
                                       expected_type='int or float')

    @classmethod
    def is_int(cls,
               value: object,
               display: bool = False) -> None:
        if type(value) != int:
            raise DataTypeNotExpectedError(actual_value=value,
                                           expected_type='int')

        if display:
            print(value)

    @classmethod
    def is_optional_int(cls,
                        value: object,
                        display: bool = False) -> None:
        if value is not None:
            cls.is_int(value, display=display)

    @classmethod
    def is_float(cls,
                 value: object,
                 display: bool = False) -> None:
        if type(value) != float:
            raise DataTypeNotExpectedError(actual_value=value,
                                           expected_type='float')

        if display:
            print(value)

    @classmethod
    def is_optional_float(cls,
                          value: object,
                          display: bool = False) -> None:
        if value is not None:
            cls.is_float(value, display=display)

    @classmethod
    def is_list(cls,
                value: object,
                display: bool = False) -> None:
        if type(value) != list:
            raise DataTypeNotExpectedError(actual_value=value,
                                           expected_type='list')

        if display:
            [print(x) for x in value]

    @classmethod
    def is_optional_list(cls,
                         value: object,
                         display: bool = False) -> None:
        if value is not None:
            cls.is_list(value, display=display)

    @classmethod
    def is_nonempty_list(cls,
                         value: object,
                         display: bool = False) -> None:
        """ Test for Non-Empty List

        Args:
            value (object): any list

        Raises:
            ContentNotExpectedError: list is empty (has no values)
        """
        cls.is_list(value, display=display)
        if not len(value):
            raise ContentNotExpectedError(actual_content=value,
                                          expected_content='Non Empty List')

    @classmethod
    def is_empty_list(cls,
                      value: object) -> None:
        """ Test for Empty List

        Args:
            value (object): any list

        Raises:
            ContentNotExpectedError: list is non-empty (has at least one value)
        """
        cls.is_list(value)
        if len(value):
            raise ContentNotExpectedError(actual_content=value,
                                          expected_content='List has Value')

    @classmethod
    def is_dict(cls,
                value: object,
                display: bool = False) -> None:
        if type(value) not in [dict, defaultdict]:
            raise DataTypeNotExpectedError(actual_value=value,
                                           expected_type='dict')

        if display:
            pprint(value)

    @classmethod
    def is_dict_of_lists(cls,
                         value: object,
                         display: bool = False) -> None:
        cls.is_dict(value)

        for k in value:
            cls.is_list(value[k])

        if display:
            pprint(value)

    @classmethod
    def _is_dict_of_list_of_type(cls,
                                 value: object,
                                 list_of_type: Callable,
                                 display: bool = False) -> None:
        cls.is_dict(value)

        for k in value:
            list_of_type(value[k])

        if display:
            pprint(value)

    @classmethod
    def is_dict_of_list_of_strs(cls,
                                value: object,
                                display: bool = False) -> None:
        return cls._is_dict_of_list_of_type(
            value=value,
            list_of_type=cls.is_list_of_str,
            display=display)

    @classmethod
    def is_dict_of_list_of_floats(cls,
                                  value: object,
                                  display: bool = False) -> None:
        return cls._is_dict_of_list_of_type(
            value=value,
            list_of_type=cls.is_list_of_float,
            display=display)

    @classmethod
    def is_dict_of_list_of_ints(cls,
                                value: object,
                                display: bool = False) -> None:
        return cls._is_dict_of_list_of_type(
            value=value,
            list_of_type=cls.is_list_of_int,
            display=display)

    @classmethod
    def is_dict_of_list_of_tuples(cls,
                                  value: object,
                                  display: bool = False) -> None:
        return cls._is_dict_of_list_of_type(
            value=value,
            list_of_type=cls.is_list_of_tuples,
            display=display)

    @classmethod
    def is_dict_of_list_of_dicts(cls,
                                 value: object,
                                 display: bool = False) -> None:
        return cls._is_dict_of_list_of_type(
            value=value,
            list_of_type=cls.is_list_of_dicts,
            display=display)

    @classmethod
    def is_dict_of_list_of_typed_dicts(cls,
                                       value: object,
                                       keys: List[str],
                                       display: bool = False) -> None:

        cls.is_dict(value)
        cls.is_list_of_str(keys)
        keys = sorted(keys)

        for k in value:

            cls.is_list_of_dicts(value[k])
            for list_item in value[k]:

                actual_keys = sorted(list_item.keys())
                if actual_keys != keys:
                    raise ContentNotExpectedError(
                        actual_content=actual_keys,
                        expected_content=keys)

        if display:
            pprint(value)

    @classmethod
    def is_nonempty_dict(cls,
                         value: object,
                         display: bool = False) -> None:
        """ Test for Non-Empty Dict

        Args:
            value (object): any dict

        Raises:
            ContentNotExpectedError: dict is empty (has no values)
        """
        cls.is_dict(value, display=display)
        if not len(value):
            raise ContentNotExpectedError(actual_content=value,
                                          expected_content='Non Empty Dict')

    @classmethod
    def is_empty_dict(cls,
                      value: object) -> None:
        """ Test for Empty Dict

        Args:
            value (object): any dict

        Raises:
            ContentNotExpectedError: dict is non-empty (has at least one value)
        """
        cls.is_dict(value)
        if len(value):
            raise ContentNotExpectedError(actual_content=value,
                                          expected_content='Dict has Value')

    @classmethod
    def is_optional_dict(cls,
                         value: object,
                         display: bool = False) -> None:
        if value is not None:
            cls.is_dict(value, display=display)

    @classmethod
    def keys(cls,
             d: dict, *args):
        """ Compare actual dictionary keys with expected dictionary keys

        Usage:
            Enforcer.keys(d_results, 'result', 'tokens')
            This will assert 'd_results' contains the keys 'result' and 'tokens' and only these keys

        Args:
            d (dict): the dictionary to test

        Raises:
            ContentNotExpectedError: the actual keys do not match the expected keys
        """
        cls.is_dict(d)
        args = sorted(args)
        keys = sorted(d.keys())
        if keys != args:
            raise ContentNotExpectedError(actual_content=keys,
                                          expected_content=args)

    @classmethod
    def is_list_of_float(cls,
                         value: object) -> None:
        """ This is a highly specialized data type checker

        Args:
            value (object): True if this is a list of float elements
        """

        def _is_list_of_floats() -> bool:
            """ List of Integers
                Sample Format:
                    ['alpha', 'beta']

            Returns:
                bool: True if list of ints
            """
            if not len(value):
                return False
            if type(value) != list:
                return False
            for item in value:
                if type(item) != float:
                    return False
            return True

        if not _is_list_of_floats():
            raise DataTypeNotExpectedError(actual_value=value,
                                           expected_type='List[float]')

    @classmethod
    def is_list_of_int(cls,
                       value: object) -> None:
        """ This is a highly specialized data type checker

        Args:
            value (object): True if this is a list of int elements
        """

        def _is_list_of_ints() -> bool:
            """ List of Integers
                Sample Format:
                    ['alpha', 'beta']

            Returns:
                bool: True if list of ints
            """
            if not len(value):
                return False
            if type(value) != list:
                return False
            for item in value:
                if type(item) != int:
                    return False
            return True

        if not _is_list_of_ints():
            raise DataTypeNotExpectedError(actual_value=value,
                                           expected_type='List[int]')

    @classmethod
    def is_list_of_str(cls,
                       value: object) -> None:
        """ This is a highly specialized data type checker

        Args:
            value (object): True if this is a list of str elements
        """

        def _is_list_of_strings() -> bool:
            """ List of Strings
                Sample Format:
                    ['alpha', 'beta']

            Returns:
                bool: True if list of strings
            """
            if not len(value):
                return False
            if type(value) != list:
                return False
            for item in value:
                if type(item) != str:
                    return False
            return True

        if not _is_list_of_strings():
            raise DataTypeNotExpectedError(actual_value=value,
                                           expected_type='List[str]')

    @classmethod
    def is_list_of_list_of_dicts(cls,
                                 value: object) -> None:
        """ This is a highly specialized data type checker

        Args:
            value (object): True if this is a list of dict elements
        """

        if type(value) != list:
            raise DataTypeNotExpectedError(actual_value=value,
                                           expected_type='List[List[Dict]]')

        [Enforcer.is_list_of_dicts(x) for x in value]

    @classmethod
    def is_list_of_tuples(cls,
                          value: object) -> None:
        """ This is a highly specialized data type checker

        Args:
            value (object): True if this is a list of tuple elements
        """

        def _is_list_of_tuples() -> bool:
            """ List of Tuples
                Sample Format:
                    [('alpha', 'beta')]

            Returns:
                bool: True if list of tuples
            """
            if not len(value):
                return False
            if type(value) != list:
                return False
            for item in value:
                if type(item) != tuple:
                    return False
            return True

        if not _is_list_of_tuples():
            raise DataTypeNotExpectedError(actual_value=value,
                                           expected_type='List[tuple]')

    @classmethod
    def is_list_of_dicts(cls,
                         value: object) -> None:
        """ This is a highly specialized data type checker

        Args:
            value (object): True if this is a list of dict elements
        """

        def _is_list_of_dicts() -> bool:
            """ List of Dicts
                Sample Format:
                    [{'entity': 'Late_Transport'}]

            Returns:
                bool: True if list of dicts
            """
            if not len(value):
                return False
            if type(value) != list:
                return False
            for item in value:
                if type(item) != dict:
                    return False
            return True

        if not _is_list_of_dicts():
            raise DataTypeNotExpectedError(actual_value=value,
                                           expected_type='List[dict]')

    @classmethod
    def is_none(cls,
                value) -> None:
        """ Assert Value is None
        this is typically used in Unit Testing1

        Args:
            value (None): a null (and therefore untyped) object

        Raises:
            ContentNotExpectedError: object is non-null
        """
        if value is not None:
            raise ContentNotExpectedError(actual_value=value,
                                          expected_type='None')

    @classmethod
    def is_json(cls,
                value: object) -> None:
        if Enforcer.is_dict(value=value, display=False):
            return True
        if Enforcer.is_list(value=value, display=False):
            return True
        return False
